/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalLine.h"
#include "HvSignalDel1.h"
#include "HvControlSystem.h"
#include "HvSignalVar.h"
#include "HvControlTabhead.h"
#include "HvSignalRPole.h"
#include "HvControlIf.h"
#include "HvSignalPhasor.h"
#include "HvControlDelay.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvControlRandom.h"
#include "HvControlBinop.h"
#include "HvControlPack.h"
#include "HvSignalTabwrite.h"
#include "HvMath.h"
#include "HvTable.h"
#include "HvControlSlice.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_NuS9aiSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nnuydczy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_JG44SkLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qhCqaZ4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qM4xkZAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Jvzy0js6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_BGHGI0ri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cXvS9dvW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FYzZBpBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cdCNZmIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5HJ1Fl30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BVGdGKy7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_m4mJcxsw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_712b6wVK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_bUx0x41T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_YF2nvvfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NxAqll4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wYEBlwEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2bBflMkS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0hymeujt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RGckDzLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RWZ2jF8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1syYnS4d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3CGZeeBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FVAJYB1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1jKqZ4um_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dbcvlYrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yyUdPhld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B1nkTw1L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ThL3HUW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_eHOlk2eJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iQIfPoUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_WpjTT3DV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2skpmcRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xRMajYOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DzyFjvyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AbAmyRn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cjL29gQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7RW7fgjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5k5ivsbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bcIcz4r0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b27Jjjf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hYmdxDjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9TcKBRJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5aj8PCRK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1V6pojx9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MZnhuNOT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_p7ZHYLM9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eUV4tEZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AbfRe2yD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x2swAg3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PD4bgTjT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LiEsnmFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xMzpxgPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_I1VCxvQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zW95CANt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VPGptPUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i18z6y1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YEBVbOsv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_itAKmlI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z19phIxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LAa0aHT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_56Irp49J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uYZy1pt5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Zi0WRh4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KZxAxM25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_h9chedN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_6nyrF5dG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_R3C7eyfp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_CjoSJo51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aEz83Sk8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q4ThEumb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jq2WDxAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FDTa85X1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ijHSTRq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DsncaMqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ylNRMRkj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_88gOCAA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_z9rWTOU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I8efcATH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hVO5SgNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FtrV1wt6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JtjxluUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_F4tNP0A2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_r6fM3TnS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UPDhVn2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pxMubSSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cela2owG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JtTisLhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fTY1UPRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_soa3Cynn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SIJxxDYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cugzhyhf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5FSZ0pnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_stp4wITM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gkqoEyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eCIYmRRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_RCc3GUxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ve9M2ORk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qdUOVsuk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eCmeQJpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MHWrjmiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QFbSobRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_0m3qdFvi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J8gO2cm9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_etMRUYOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qSrIhny1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lToQiI2l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FQenoWlO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6W4i83xP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vkTirlbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EoBpXZ9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UBRx8hv8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A3SpHqo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BGKLXkTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kqsbff09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_wYjfkz5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_evTQPtiO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_E6r5Ru8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Y6WD4HFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dHnxAkE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hkrqCeQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_YsdnoXKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LZYSE4Vz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HXfQ72h8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s1IfCv4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fM7RvmcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fJmhV4t7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vh5d1jN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZE0TpkEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hAKkx5fM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wWJSZVaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t06zKqsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p6FI3dYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KxPCen7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_QuQM6A2k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sgipj7uo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Mfz8HJO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fczWhhYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_fusv8m8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GwalW2Bg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_5MF1l418_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rPb6Ee3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_99dsvrey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RtZOvZwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QtoUmndu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lGddpkmz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ovC6Yr1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CpkmZiQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YgeVlmuD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kZPi5rGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p6QoUMDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_53mC33Uw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pTMDyAlK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IKtkOjbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r4ZNfR46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TiIJFmDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PPPhSiK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Vs7Wjymr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_KZNstOC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_w9caY7Uc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wyv09UrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M7TlCpM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HpdMdz6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nHALnscd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0EGbyPFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FblrJky0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cimo71OP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DdQ67tJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SwMRznUO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_M9tPPwPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3PJe0y2t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_mVVXL3gL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_I5hYQdPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VBMVaM1V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CKlqScuW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1Xpywmp2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wPPVG0ZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kz5MOPRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jKEKrUXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZfxfaPC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ua8Z5PQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rwYThOag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9DyEEwnT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wIKeDLmL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_dns5QhSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_81RcK0Og_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VkNu1To5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rqNIbWel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W8UVSkxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iKqoXk8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_deJ5WOZg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x0WVpsp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m11cfVDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tSmn5Ern_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_XooNIOTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uqiIkWcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_eM9r5cN4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_rX3INTci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_lcWhYsi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b0xHivK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EyH5N1z4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UVGqZrnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2fj97NsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z6zZkpRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0aY2ZtVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Tl8xzhKK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_tZZFKcTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DwID7hFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oRgtbxkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kKuDxKFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nki7jl8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HoJO6Bh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F3vZFm9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Suo4GIhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9GnrCLhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jh7uqKkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OPErtCGZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zzwUbEsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_APZFXISU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VlOwzHEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bonT6GsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z9wUw8rc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NItNdQ8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RZLwPua8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MeP1UPx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9jhCOqBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GcUTu1YY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dPvfMipW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zDuUzF87_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hkSMAwHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sQviBSo2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_XMPwBhL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_G7vqWhgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fZ8tE2o9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jcVzJfyi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KBjAd6pb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0hRyKnIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3i3K360P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1bsAVS3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_C8NNnfoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lutDnQbB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TycBXijX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Eds6lj3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VlmMxUat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5AfNx0ai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Y35u61Z4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rG9vBysS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IDvTA7YI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iFvl9fSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_maWOmtHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vifmESdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hlHtWUTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FwFAg4Bj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8SeafQfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_juzukQ9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GLfzEljb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bQUCk6AR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Td9JGdlm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m2OBY37s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_36n23msc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mn9KkFVS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_z6hygjnf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5kyCMF9y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_F9EM2SD6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_g2aqpmME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2ofAdCJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jQOlPhc5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nk59Ui4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OI1FXXvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4Po66TmK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_be2xjSFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_LoVnC1s1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WmfzDFEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dFW60pTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RTM4oqO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_I9CSEhE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OAOy2YXY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_mmMhnqzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vjq48qQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rwCimj9M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qEniSJLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_E0V93svm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YHpM9b1S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XAJD0Fty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uX711ijy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zzz5I2dZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IvEh91qy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5n8AcWgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FZHvTbuo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XvjjT6UU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QuHieZvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CzLcLlwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4FGqJnY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_0umwDOyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kfM1lUkO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_9n4MnQKJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Jka8xjLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XtdqAFHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T3twXdAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cKLAKYps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QQRQ6JCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fz9MYGuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wxHZr5px_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_UdgDecLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_54Ro4N8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3dBnk7SX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IKyRlgPq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7q1kKr6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CuVImasy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Ufg6585U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ds4AMR41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8rDU3c5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q8JY2Rz1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Qf5CHgrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AYraqqYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_28uTJk9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l8rKl1d4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EfLroEe0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WcmTiTRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I1gjDr1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ppfXEzes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gMVhnaBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jN1Lu6Rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_feRDCwca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bJvEkD2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dpgntKfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SwvT9vFi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Y2X1i9jI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_2uj5YxwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uWXncdgo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yAcwmfJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9pZxBkwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xrXLd6Xl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_25e0Bnmr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W1GkZNFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_uCbeNXpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Es2jrWxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8peuKYYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xebNQcRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_l6pT83yb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xLMIJi25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_K0fbaYQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nsMlBsCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WntdH5W0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hfK9JrFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rObJRMXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lkLXarTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wsxnBYjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4DjD3WNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MMkQjOv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mlFfTLtA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TYZinHLx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aldc6gic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bXsprY2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FlsH29Xi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yynOTIl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MBuhRjlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_8uRy1253_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wvHSQDCP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_PQHu2P7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_8O0gCo8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ogW4piFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WG0j97f5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MxNbr9Cd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_otPFPupy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HBjIkvf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l0sdLYRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_BpL6lLZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oDjx0RhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FCM6uBSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3haIMTYF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_o8LizZKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OKzfgyze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_RUAlilQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DVe1y8ou_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UD7OtR63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_21OS53cJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_V1gYJ3GZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CmW3W9dV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AweSXAHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2jh7hJEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OMm3Oizj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hZU31R0J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9MJJszdq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eKpnxgBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yZnyRftw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sqsUvYHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_w3cNNZoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qjB2tIsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wkwwG3Yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YSDsYLRk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_6OomW9lO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_Bo97sIs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bmtt8a9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R0MIXtBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k31rm0FO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vb4OiDQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uhPkDXz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XHad0s17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_iFVFwI2t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZOg6Ut9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QFXUaWbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_doe4sVsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dwiY10yd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2eo68Ccm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_crpjM7df_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vODBxTv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LpPyYIQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ehmam7bQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_paz7oSFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yeVCqb1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Glx5csU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ey0shCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WiyHzUq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5tOjUARf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qLVNhUXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qlc8YkfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jAdqsPzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3NoCbM0d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9SSED0mx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_PeYXmJAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6miJPc0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Z71twnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5LKMiKle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OCGFor4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GiHhOvtb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mPSkYeSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UP91xxwb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VsCH8R8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yAwYKXVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H0ojwI1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gAsejT1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lGpxBhXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b050hDs4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NaaCepEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nuJYuqLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WKk7Znd6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5zyBMGaU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u0QX53CW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_trP9xK6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jACILsia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EBdMiDpH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hoxAKGIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3CYg5Cfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ITPYMVAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zu2VHBbR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iGQRex3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ixZfiBm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zfBC8fCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Iywf6hxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G974W7RL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4GtU24kP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DAZqdg2v_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wx5GSikK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LKhgicFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nBtlttKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4BGuzGzl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_34YX189G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2qWaiUVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wJeFhPh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lPzN2hHG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JVeJZQlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FaxYgj3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HUGKnVDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1Mk1isRB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DlDhlj25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RmCzKcYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NHkqsLcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wOnpFJRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_XK0AeHII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_scskPBdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pKYHl1t8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Tg8mV1qy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ZNNyEAR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ljosD6FB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ZIIKS4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5IP1D3s9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FaKLf8BM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UYR9wn1P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ikx9TjWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9GgRbmjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_DJP3AXP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GR02AO0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Agty8oMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AfJbEMbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_XwF5bRc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ae3fnqgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Jub5sovz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J1MBzJnj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mNBTi29D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PJRY7r4I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QK43ipO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LOI63B1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_at5plSj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GrhkaWe4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YmhJnugk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6KbFr8cC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lcPRsVDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fiV7Iwl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0pfPATDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_buk6j1Nq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_3meWK5EZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oXG49wk4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NFLK5iXm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_1Yhi60He_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C7NnIuQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5zuemPxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lfFOoFIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Sslsi5Tu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_c2FbJuk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pU8xgxx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iaaRNkVl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mwXpkthl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wsSj8phQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mSnf3SOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pLtB8LiF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2xY2naIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0Zs6UDVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W08rLIXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RKWXo01B_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TYmG8ewk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_5mBlFGdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wZSctSIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KoQlJeJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9yIzeT0I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SXyRTvON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9IhOUWqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_98dYzQjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WKQ0n1dc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3aWzdW2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VaxGdPrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CK3P2WPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZWJvd87m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ivHT4PL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EC2Ck2wz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gyqY7qxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_96kFO69x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OVhNU3Fb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QdUeQ6HJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MuZZykkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XqQX8EkN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ld3g1cBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gpHxvZpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b3dMZOos_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_An33hC8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FqV0Fs6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K9aO3TBP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GFmcRnPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kcchCSrU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UMyuezEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DyHrX8GB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YAiJShzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f86yKFAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lX1sQZlX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lUyWBq5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dCEsVfF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_37Cda7P8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bItenKJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tj21tzHo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtgVuyV4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oupes67s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UfrnvYF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NRR9axaq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WJkMyV6s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_91l5ghBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c2BlAhDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8PdhmFOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q77bRDLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sAxrlY2M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Btk1pnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fqvthkgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kGtSHAjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GAcZNgIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BFMl6c94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yrLDjnzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V11K51fZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4vOLHPoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uD4qg8WM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8qL8OkJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zS7O8Mu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mvVn7Lhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_f9z9NnHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TGy26br0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WTfWgqdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_D4jcvcbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8coIzRxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6uQ5M3xB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nayBxOBD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FoloaZKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5q6CEmUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_p7PtGAqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X6ZWXOzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7BTqB12h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_w2KkKjDI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Z9WrAuVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O2nfv7Gp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qmnwyZGY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ieSZwpIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fGU4aIrK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZmHaNCKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TvyHAR7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bMTUVmQR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Gz5bbhvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9S59uWue_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_1IFokgMu;
  SignalLine sLine_vtukoKc8;
  SignalLine sLine_T0NVDXRV;
  SignalTabhead sTabhead_9zQgcjLm;
  SignalTabread sTabread_eK64ZKON;
  SignalTabread sTabread_0GBEWgNR;
  SignalTabhead sTabhead_jY42P5J5;
  SignalTabread sTabread_Ht7FHk2X;
  SignalTabread sTabread_LCBNfAQX;
  SignalTabwrite sTabwrite_3c2aRRH4;
  SignalRPole sRPole_yjdV9Ifb;
  SignalDel1 sDel1_PwMzVesj;
  SignalTabread sTabread_Jub5sovz;
  SignalTabwrite sTabwrite_ONUMy9Wr;
  SignalTabread sTabread_r6fM3TnS;
  SignalRPole sRPole_jmSuMbpx;
  SignalLine sLine_BtEoMJDi;
  SignalLine sLine_cCK8SawI;
  SignalTabread sTabread_Y35u61Z4;
  SignalTabread sTabread_mmMhnqzW;
  SignalTabread sTabread_Ufg6585U;
  SignalTabread sTabread_K0fbaYQX;
  SignalTabread sTabread_crpjM7df;
  SignalTabread sTabread_RUAlilQT;
  SignalTabwrite sTabwrite_0Pl3dNIQ;
  SignalTabwrite sTabwrite_UUqDgrLU;
  SignalTabwrite sTabwrite_AwMN1Bx7;
  SignalTabwrite sTabwrite_z0p9VhpL;
  SignalTabwrite sTabwrite_8a7dg4qE;
  SignalTabwrite sTabwrite_bqjiApZL;
  SignalTabread sTabread_0m3qdFvi;
  SignalRPole sRPole_jctrbMkd;
  SignalTabread sTabread_YsdnoXKM;
  SignalRPole sRPole_usYgsXdz;
  SignalTabread sTabread_5MF1l418;
  SignalRPole sRPole_GmkMZkVb;
  SignalTabwrite sTabwrite_rseLYbiB;
  SignalTabwrite sTabwrite_3AKmkRUc;
  SignalTabwrite sTabwrite_D7NUIqpq;
  SignalTabwrite sTabwrite_Ye1OuG4u;
  SignalLine sLine_cylkODwp;
  ControlVar cVar_NuS9aiSu;
  ControlVar cVar_nnuydczy;
  ControlPack cPack_JG44SkLD;
  ControlBinop cBinop_qM4xkZAB;
  ControlVar cVar_Jvzy0js6;
  ControlPack cPack_BGHGI0ri;
  ControlVar cVar_cXvS9dvW;
  ControlVar cVar_FYzZBpBe;
  ControlDelay cDelay_BVGdGKy7;
  ControlDelay cDelay_m4mJcxsw;
  ControlBinop cBinop_bUx0x41T;
  HvTable hTable_YF2nvvfg;
  ControlBinop cBinop_wYEBlwEC;
  ControlVar cVar_FVAJYB1A;
  ControlBinop cBinop_dbcvlYrn;
  ControlBinop cBinop_B1nkTw1L;
  SignalVarf sVarf_rNUcEcpT;
  SignalVarf sVarf_LMTUOOZI;
  SignalVarf sVarf_0WEZb33N;
  ControlVar cVar_iQIfPoUW;
  ControlBinop cBinop_2skpmcRc;
  ControlBinop cBinop_DzyFjvyY;
  SignalVarf sVarf_0gnUWy3M;
  SignalVarf sVarf_d9Ae8n2Q;
  SignalVarf sVarf_ZqEBJQ5U;
  ControlBinop cBinop_AbAmyRn1;
  ControlBinop cBinop_cjL29gQn;
  ControlBinop cBinop_bcIcz4r0;
  ControlBinop cBinop_b27Jjjf3;
  ControlBinop cBinop_hYmdxDjk;
  ControlBinop cBinop_9TcKBRJ7;
  ControlBinop cBinop_5aj8PCRK;
  ControlBinop cBinop_x2swAg3g;
  ControlBinop cBinop_PD4bgTjT;
  SignalVarf sVarf_aX7BAuvn;
  ControlVar cVar_LiEsnmFN;
  ControlBinop cBinop_zW95CANt;
  ControlBinop cBinop_VPGptPUo;
  ControlBinop cBinop_YEBVbOsv;
  ControlBinop cBinop_itAKmlI6;
  ControlBinop cBinop_z19phIxF;
  ControlBinop cBinop_LAa0aHT8;
  ControlBinop cBinop_56Irp49J;
  SignalVarf sVarf_5H2KqyCc;
  ControlBinop cBinop_Zi0WRh4X;
  ControlRandom cRandom_h9chedN5;
  ControlSlice cSlice_6nyrF5dG;
  ControlDelay cDelay_CjoSJo51;
  ControlVar cVar_FDTa85X1;
  ControlBinop cBinop_DsncaMqV;
  ControlBinop cBinop_ylNRMRkj;
  ControlBinop cBinop_88gOCAA8;
  ControlTabhead cTabhead_z9rWTOU3;
  ControlVar cVar_FtrV1wt6;
  ControlDelay cDelay_JtjxluUu;
  ControlDelay cDelay_F4tNP0A2;
  ControlBinop cBinop_UPDhVn2I;
  ControlBinop cBinop_pxMubSSH;
  ControlBinop cBinop_cela2owG;
  ControlBinop cBinop_Cugzhyhf;
  ControlBinop cBinop_stp4wITM;
  ControlBinop cBinop_5gkqoEyN;
  ControlTabhead cTabhead_RCc3GUxr;
  ControlVar cVar_eCmeQJpV;
  ControlDelay cDelay_MHWrjmiA;
  ControlDelay cDelay_QFbSobRz;
  ControlBinop cBinop_J8gO2cm9;
  ControlBinop cBinop_etMRUYOj;
  ControlBinop cBinop_qSrIhny1;
  ControlBinop cBinop_EoBpXZ9U;
  ControlBinop cBinop_A3SpHqo1;
  ControlBinop cBinop_BGKLXkTf;
  ControlTabhead cTabhead_wYjfkz5x;
  ControlVar cVar_Y6WD4HFO;
  ControlDelay cDelay_dHnxAkE1;
  ControlDelay cDelay_hkrqCeQn;
  ControlBinop cBinop_LZYSE4Vz;
  ControlBinop cBinop_HXfQ72h8;
  ControlBinop cBinop_s1IfCv4n;
  ControlBinop cBinop_hAKkx5fM;
  ControlBinop cBinop_t06zKqsy;
  ControlBinop cBinop_p6FI3dYr;
  ControlTabhead cTabhead_QuQM6A2k;
  ControlVar cVar_fczWhhYI;
  ControlDelay cDelay_fusv8m8e;
  ControlDelay cDelay_GwalW2Bg;
  ControlBinop cBinop_rPb6Ee3E;
  ControlBinop cBinop_99dsvrey;
  ControlBinop cBinop_RtZOvZwh;
  ControlBinop cBinop_YgeVlmuD;
  ControlBinop cBinop_p6QoUMDc;
  ControlBinop cBinop_53mC33Uw;
  ControlDelay cDelay_TiIJFmDH;
  ControlDelay cDelay_PPPhSiK9;
  ControlBinop cBinop_KZNstOC1;
  HvTable hTable_w9caY7Uc;
  ControlBinop cBinop_M7TlCpM6;
  ControlDelay cDelay_SwMRznUO;
  ControlDelay cDelay_M9tPPwPH;
  ControlBinop cBinop_mVVXL3gL;
  HvTable hTable_I5hYQdPe;
  ControlBinop cBinop_CKlqScuW;
  ControlDelay cDelay_rwYThOag;
  ControlDelay cDelay_9DyEEwnT;
  ControlBinop cBinop_dns5QhSK;
  HvTable hTable_81RcK0Og;
  ControlBinop cBinop_rqNIbWel;
  ControlDelay cDelay_XooNIOTk;
  ControlDelay cDelay_uqiIkWcI;
  ControlBinop cBinop_rX3INTci;
  HvTable hTable_lcWhYsi7;
  ControlBinop cBinop_EyH5N1z4;
  ControlPack cPack_Tl8xzhKK;
  ControlPack cPack_tZZFKcTY;
  ControlBinop cBinop_DwID7hFx;
  ControlBinop cBinop_oRgtbxkO;
  ControlVar cVar_kKuDxKFE;
  ControlBinop cBinop_F3vZFm9o;
  ControlBinop cBinop_Suo4GIhA;
  SignalVarf sVarf_y97o7vwD;
  ControlBinop cBinop_Jh7uqKkA;
  ControlBinop cBinop_OPErtCGZ;
  ControlBinop cBinop_zzwUbEsu;
  SignalVarf sVarf_Lk5DusoI;
  ControlVar cVar_APZFXISU;
  ControlVar cVar_VlOwzHEz;
  ControlVar cVar_bonT6GsE;
  ControlVar cVar_Z9wUw8rc;
  ControlIf cIf_NItNdQ8e;
  ControlBinop cBinop_RZLwPua8;
  ControlBinop cBinop_MeP1UPx6;
  ControlBinop cBinop_9jhCOqBg;
  ControlDelay cDelay_zDuUzF87;
  ControlDelay cDelay_hkSMAwHX;
  ControlBinop cBinop_XMPwBhL6;
  HvTable hTable_G7vqWhgt;
  ControlBinop cBinop_jcVzJfyi;
  ControlTabhead cTabhead_C8NNnfoA;
  ControlVar cVar_Eds6lj3R;
  ControlDelay cDelay_VlmMxUat;
  ControlDelay cDelay_5AfNx0ai;
  ControlBinop cBinop_rG9vBysS;
  ControlBinop cBinop_IDvTA7YI;
  ControlBinop cBinop_iFvl9fSK;
  ControlBinop cBinop_8SeafQfN;
  ControlBinop cBinop_GLfzEljb;
  ControlBinop cBinop_bQUCk6AR;
  ControlDelay cDelay_mn9KkFVS;
  ControlDelay cDelay_z6hygjnf;
  ControlBinop cBinop_F9EM2SD6;
  HvTable hTable_g2aqpmME;
  ControlBinop cBinop_jQOlPhc5;
  ControlTabhead cTabhead_LoVnC1s1;
  ControlVar cVar_RTM4oqO0;
  ControlDelay cDelay_I9CSEhE4;
  ControlDelay cDelay_OAOy2YXY;
  ControlBinop cBinop_Vjq48qQ6;
  ControlBinop cBinop_rwCimj9M;
  ControlBinop cBinop_qEniSJLA;
  ControlBinop cBinop_Zzz5I2dZ;
  ControlBinop cBinop_5n8AcWgI;
  ControlBinop cBinop_FZHvTbuo;
  ControlDelay cDelay_4FGqJnY7;
  ControlDelay cDelay_0umwDOyP;
  ControlBinop cBinop_9n4MnQKJ;
  HvTable hTable_Jka8xjLg;
  ControlBinop cBinop_T3twXdAR;
  ControlTabhead cTabhead_UdgDecLP;
  ControlVar cVar_IKyRlgPq;
  ControlDelay cDelay_7q1kKr6R;
  ControlDelay cDelay_CuVImasy;
  ControlBinop cBinop_ds4AMR41;
  ControlBinop cBinop_8rDU3c5R;
  ControlBinop cBinop_q8JY2Rz1;
  ControlBinop cBinop_EfLroEe0;
  ControlBinop cBinop_I1gjDr1r;
  ControlBinop cBinop_ppfXEzes;
  ControlDelay cDelay_bJvEkD2I;
  ControlDelay cDelay_dpgntKfU;
  ControlBinop cBinop_Y2X1i9jI;
  HvTable hTable_2uj5YxwG;
  ControlBinop cBinop_yAcwmfJF;
  ControlTabhead cTabhead_uCbeNXpV;
  ControlVar cVar_xebNQcRz;
  ControlDelay cDelay_l6pT83yb;
  ControlDelay cDelay_xLMIJi25;
  ControlBinop cBinop_nsMlBsCw;
  ControlBinop cBinop_WntdH5W0;
  ControlBinop cBinop_hfK9JrFd;
  ControlBinop cBinop_MMkQjOv3;
  ControlBinop cBinop_TYZinHLx;
  ControlBinop cBinop_aldc6gic;
  ControlDelay cDelay_MBuhRjlT;
  ControlDelay cDelay_8uRy1253;
  ControlBinop cBinop_PQHu2P7N;
  HvTable hTable_8O0gCo8i;
  ControlBinop cBinop_WG0j97f5;
  ControlTabhead cTabhead_BpL6lLZj;
  ControlVar cVar_3haIMTYF;
  ControlDelay cDelay_o8LizZKQ;
  ControlDelay cDelay_OKzfgyze;
  ControlBinop cBinop_DVe1y8ou;
  ControlBinop cBinop_UD7OtR63;
  ControlBinop cBinop_21OS53cJ;
  ControlBinop cBinop_OMm3Oizj;
  ControlBinop cBinop_9MJJszdq;
  ControlBinop cBinop_eKpnxgBT;
  ControlDelay cDelay_qjB2tIsY;
  ControlDelay cDelay_wkwwG3Yw;
  ControlBinop cBinop_6OomW9lO;
  HvTable hTable_Bo97sIs9;
  ControlBinop cBinop_R0MIXtBY;
  ControlTabhead cTabhead_iFVFwI2t;
  ControlVar cVar_doe4sVsl;
  ControlDelay cDelay_dwiY10yd;
  ControlDelay cDelay_2eo68Ccm;
  ControlBinop cBinop_vODBxTv7;
  ControlBinop cBinop_LpPyYIQx;
  ControlBinop cBinop_Ehmam7bQ;
  ControlBinop cBinop_WiyHzUq5;
  ControlBinop cBinop_qLVNhUXF;
  ControlBinop cBinop_Qlc8YkfZ;
  ControlVar cVar_3NoCbM0d;
  ControlVar cVar_9SSED0mx;
  ControlPack cPack_PeYXmJAV;
  ControlVar cVar_6miJPc0C;
  ControlBinop cBinop_OCGFor4F;
  ControlBinop cBinop_GiHhOvtb;
  SignalVarf sVarf_6Fj9NAGv;
  ControlBinop cBinop_UP91xxwb;
  ControlBinop cBinop_VsCH8R8n;
  ControlBinop cBinop_yAwYKXVc;
  SignalVarf sVarf_xUumtjRD;
  ControlVar cVar_H0ojwI1s;
  ControlBinop cBinop_b050hDs4;
  ControlBinop cBinop_NaaCepEn;
  SignalVarf sVarf_sbeYoikH;
  ControlBinop cBinop_WKk7Znd6;
  ControlBinop cBinop_5zyBMGaU;
  ControlBinop cBinop_u0QX53CW;
  SignalVarf sVarf_sXpfjFBI;
  ControlVar cVar_trP9xK6e;
  ControlBinop cBinop_hoxAKGIM;
  ControlBinop cBinop_3CYg5Cfu;
  SignalVarf sVarf_fdNcFzVT;
  ControlBinop cBinop_zu2VHBbR;
  ControlBinop cBinop_iGQRex3u;
  ControlBinop cBinop_ixZfiBm3;
  SignalVarf sVarf_Bsc9ibju;
  ControlBinop cBinop_zfBC8fCk;
  ControlBinop cBinop_G974W7RL;
  ControlBinop cBinop_4GtU24kP;
  ControlDelay cDelay_wx5GSikK;
  ControlVar cVar_34YX189G;
  ControlBinop cBinop_wJeFhPh8;
  ControlBinop cBinop_lPzN2hHG;
  ControlBinop cBinop_JVeJZQlT;
  ControlVar cVar_FaxYgj3y;
  ControlVar cVar_HUGKnVDt;
  ControlIf cIf_RmCzKcYI;
  ControlBinop cBinop_NHkqsLcc;
  ControlDelay cDelay_scskPBdE;
  ControlDelay cDelay_pKYHl1t8;
  ControlBinop cBinop_ZNNyEAR6;
  HvTable hTable_ljosD6FB;
  ControlBinop cBinop_5IP1D3s9;
  ControlTabhead cTabhead_DJP3AXP2;
  ControlVar cVar_AfJbEMbS;
  ControlDelay cDelay_XwF5bRc6;
  ControlDelay cDelay_ae3fnqgj;
  ControlBinop cBinop_J1MBzJnj;
  ControlBinop cBinop_mNBTi29D;
  ControlBinop cBinop_PJRY7r4I;
  ControlBinop cBinop_YmhJnugk;
  ControlBinop cBinop_lcPRsVDe;
  ControlBinop cBinop_fiV7Iwl9;
  ControlVar cVar_oXG49wk4;
  ControlVar cVar_C7NnIuQo;
  ControlVar cVar_5zuemPxv;
  ControlVar cVar_lfFOoFIh;
  ControlVar cVar_Sslsi5Tu;
  ControlVar cVar_c2FbJuk3;
  ControlIf cIf_mwXpkthl;
  ControlBinop cBinop_wsSj8phQ;
  ControlVar cVar_mSnf3SOK;
  ControlIf cIf_0Zs6UDVb;
  ControlBinop cBinop_W08rLIXe;
  ControlSlice cSlice_TYmG8ewk;
  ControlSlice cSlice_5mBlFGdd;
  ControlVar cVar_wZSctSIf;
  ControlIf cIf_KoQlJeJT;
  ControlBinop cBinop_9IhOUWqC;
  ControlIf cIf_3aWzdW2n;
  ControlIf cIf_VaxGdPrN;
  ControlIf cIf_CK3P2WPm;
  ControlIf cIf_ZWJvd87m;
  ControlIf cIf_ivHT4PL9;
  SignalVarf sVarf_5PLINncd;
  ControlBinop cBinop_QdUeQ6HJ;
  ControlBinop cBinop_MuZZykkb;
  ControlBinop cBinop_Ld3g1cBl;
  ControlBinop cBinop_gpHxvZpz;
  SignalVarf sVarf_8Dsa5Syk;
  ControlBinop cBinop_An33hC8q;
  ControlBinop cBinop_FqV0Fs6A;
  SignalVarf sVarf_uwBRB05F;
  SignalVarf sVarf_kHclYqcP;
  ControlBinop cBinop_DyHrX8GB;
  ControlBinop cBinop_YAiJShzO;
  ControlBinop cBinop_f86yKFAT;
  ControlBinop cBinop_lX1sQZlX;
  ControlBinop cBinop_dCEsVfF5;
  ControlBinop cBinop_37Cda7P8;
  ControlBinop cBinop_bItenKJT;
  ControlBinop cBinop_Tj21tzHo;
  ControlBinop cBinop_oupes67s;
  ControlBinop cBinop_UfrnvYF6;
  ControlBinop cBinop_NRR9axaq;
  ControlBinop cBinop_BFMl6c94;
  ControlBinop cBinop_yrLDjnzJ;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
