/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_1IFokgMu, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_vtukoKc8);
  numBytes += sLine_init(&sLine_T0NVDXRV);
  numBytes += sTabhead_init(&sTabhead_9zQgcjLm, &hTable_YF2nvvfg);
  numBytes += sTabread_init(&sTabread_eK64ZKON, &hTable_YF2nvvfg, false);
  numBytes += sTabread_init(&sTabread_0GBEWgNR, &hTable_YF2nvvfg, false);
  numBytes += sTabhead_init(&sTabhead_jY42P5J5, &hTable_YF2nvvfg);
  numBytes += sTabread_init(&sTabread_Ht7FHk2X, &hTable_YF2nvvfg, false);
  numBytes += sTabread_init(&sTabread_LCBNfAQX, &hTable_YF2nvvfg, false);
  numBytes += sTabwrite_init(&sTabwrite_3c2aRRH4, &hTable_YF2nvvfg);
  numBytes += sRPole_init(&sRPole_yjdV9Ifb);
  numBytes += sDel1_init(&sDel1_PwMzVesj);
  numBytes += sTabread_init(&sTabread_Jub5sovz, &hTable_ljosD6FB, true);
  numBytes += sTabwrite_init(&sTabwrite_ONUMy9Wr, &hTable_ljosD6FB);
  numBytes += sTabread_init(&sTabread_r6fM3TnS, &hTable_w9caY7Uc, true);
  numBytes += sRPole_init(&sRPole_jmSuMbpx);
  numBytes += sLine_init(&sLine_BtEoMJDi);
  numBytes += sLine_init(&sLine_cCK8SawI);
  numBytes += sTabread_init(&sTabread_Y35u61Z4, &hTable_G7vqWhgt, true);
  numBytes += sTabread_init(&sTabread_mmMhnqzW, &hTable_g2aqpmME, true);
  numBytes += sTabread_init(&sTabread_Ufg6585U, &hTable_Jka8xjLg, true);
  numBytes += sTabread_init(&sTabread_K0fbaYQX, &hTable_2uj5YxwG, true);
  numBytes += sTabread_init(&sTabread_crpjM7df, &hTable_Bo97sIs9, true);
  numBytes += sTabread_init(&sTabread_RUAlilQT, &hTable_8O0gCo8i, true);
  numBytes += sTabwrite_init(&sTabwrite_0Pl3dNIQ, &hTable_G7vqWhgt);
  numBytes += sTabwrite_init(&sTabwrite_UUqDgrLU, &hTable_g2aqpmME);
  numBytes += sTabwrite_init(&sTabwrite_AwMN1Bx7, &hTable_Jka8xjLg);
  numBytes += sTabwrite_init(&sTabwrite_z0p9VhpL, &hTable_2uj5YxwG);
  numBytes += sTabwrite_init(&sTabwrite_8a7dg4qE, &hTable_8O0gCo8i);
  numBytes += sTabwrite_init(&sTabwrite_bqjiApZL, &hTable_Bo97sIs9);
  numBytes += sTabread_init(&sTabread_0m3qdFvi, &hTable_I5hYQdPe, true);
  numBytes += sRPole_init(&sRPole_jctrbMkd);
  numBytes += sTabread_init(&sTabread_YsdnoXKM, &hTable_81RcK0Og, true);
  numBytes += sRPole_init(&sRPole_usYgsXdz);
  numBytes += sTabread_init(&sTabread_5MF1l418, &hTable_lcWhYsi7, true);
  numBytes += sRPole_init(&sRPole_GmkMZkVb);
  numBytes += sTabwrite_init(&sTabwrite_rseLYbiB, &hTable_w9caY7Uc);
  numBytes += sTabwrite_init(&sTabwrite_3AKmkRUc, &hTable_I5hYQdPe);
  numBytes += sTabwrite_init(&sTabwrite_D7NUIqpq, &hTable_81RcK0Og);
  numBytes += sTabwrite_init(&sTabwrite_Ye1OuG4u, &hTable_lcWhYsi7);
  numBytes += sLine_init(&sLine_cylkODwp);
  numBytes += cVar_init_f(&cVar_NuS9aiSu, 0.0f);
  numBytes += cVar_init_f(&cVar_nnuydczy, 0.0f);
  numBytes += cPack_init(&cPack_JG44SkLD, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_Jvzy0js6, 0.0f);
  numBytes += cPack_init(&cPack_BGHGI0ri, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_cXvS9dvW, 0.0f);
  numBytes += cVar_init_f(&cVar_FYzZBpBe, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BVGdGKy7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_m4mJcxsw, 0.0f);
  numBytes += hTable_init(&hTable_YF2nvvfg, 256);
  numBytes += cVar_init_s(&cVar_FVAJYB1A, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_rNUcEcpT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LMTUOOZI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0WEZb33N, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_iQIfPoUW, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_0gnUWy3M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_d9Ae8n2Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZqEBJQ5U, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_AbAmyRn1, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_aX7BAuvn, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_LiEsnmFN, 0.0f);
  numBytes += cBinop_init(&cBinop_56Irp49J, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_5H2KqyCc, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_h9chedN5, -1461121413);
  numBytes += cSlice_init(&cSlice_6nyrF5dG, 1, 1);
  numBytes += cDelay_init(this, &cDelay_CjoSJo51, 0.0f);
  numBytes += cVar_init_f(&cVar_FDTa85X1, 5.0f);
  numBytes += cBinop_init(&cBinop_88gOCAA8, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_z9rWTOU3, &hTable_w9caY7Uc);
  numBytes += cVar_init_s(&cVar_FtrV1wt6, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_JtjxluUu, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_F4tNP0A2, 0.0f);
  numBytes += cBinop_init(&cBinop_UPDhVn2I, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_cela2owG, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Cugzhyhf, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_5gkqoEyN, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_RCc3GUxr, &hTable_I5hYQdPe);
  numBytes += cVar_init_s(&cVar_eCmeQJpV, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_MHWrjmiA, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_QFbSobRz, 0.0f);
  numBytes += cBinop_init(&cBinop_J8gO2cm9, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_qSrIhny1, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_EoBpXZ9U, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_BGKLXkTf, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_wYjfkz5x, &hTable_81RcK0Og);
  numBytes += cVar_init_s(&cVar_Y6WD4HFO, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_dHnxAkE1, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_hkrqCeQn, 0.0f);
  numBytes += cBinop_init(&cBinop_LZYSE4Vz, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_s1IfCv4n, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_hAKkx5fM, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_p6FI3dYr, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_QuQM6A2k, &hTable_lcWhYsi7);
  numBytes += cVar_init_s(&cVar_fczWhhYI, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_fusv8m8e, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_GwalW2Bg, 0.0f);
  numBytes += cBinop_init(&cBinop_rPb6Ee3E, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_RtZOvZwh, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_YgeVlmuD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_53mC33Uw, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_TiIJFmDH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PPPhSiK9, 0.0f);
  numBytes += hTable_init(&hTable_w9caY7Uc, 256);
  numBytes += cDelay_init(this, &cDelay_SwMRznUO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_M9tPPwPH, 0.0f);
  numBytes += hTable_init(&hTable_I5hYQdPe, 256);
  numBytes += cDelay_init(this, &cDelay_rwYThOag, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9DyEEwnT, 0.0f);
  numBytes += hTable_init(&hTable_81RcK0Og, 256);
  numBytes += cDelay_init(this, &cDelay_XooNIOTk, 0.0f);
  numBytes += cDelay_init(this, &cDelay_uqiIkWcI, 0.0f);
  numBytes += hTable_init(&hTable_lcWhYsi7, 256);
  numBytes += cPack_init(&cPack_Tl8xzhKK, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_tZZFKcTY, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_kKuDxKFE, 22050.0f);
  numBytes += cBinop_init(&cBinop_F3vZFm9o, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_y97o7vwD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Lk5DusoI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_APZFXISU, 0.0f);
  numBytes += cVar_init_f(&cVar_VlOwzHEz, 0.0f);
  numBytes += cVar_init_f(&cVar_bonT6GsE, 0.0f);
  numBytes += cVar_init_f(&cVar_Z9wUw8rc, 0.0f);
  numBytes += cIf_init(&cIf_NItNdQ8e, false);
  numBytes += cDelay_init(this, &cDelay_zDuUzF87, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hkSMAwHX, 0.0f);
  numBytes += hTable_init(&hTable_G7vqWhgt, 256);
  numBytes += cTabhead_init(&cTabhead_C8NNnfoA, &hTable_G7vqWhgt);
  numBytes += cVar_init_s(&cVar_Eds6lj3R, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_VlmMxUat, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_5AfNx0ai, 0.0f);
  numBytes += cBinop_init(&cBinop_rG9vBysS, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_iFvl9fSK, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_8SeafQfN, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_bQUCk6AR, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_mn9KkFVS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_z6hygjnf, 0.0f);
  numBytes += hTable_init(&hTable_g2aqpmME, 256);
  numBytes += cTabhead_init(&cTabhead_LoVnC1s1, &hTable_g2aqpmME);
  numBytes += cVar_init_s(&cVar_RTM4oqO0, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_I9CSEhE4, 25.796f);
  numBytes += cDelay_init(this, &cDelay_OAOy2YXY, 0.0f);
  numBytes += cBinop_init(&cBinop_Vjq48qQ6, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_qEniSJLA, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Zzz5I2dZ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_FZHvTbuo, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_4FGqJnY7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_0umwDOyP, 0.0f);
  numBytes += hTable_init(&hTable_Jka8xjLg, 256);
  numBytes += cTabhead_init(&cTabhead_UdgDecLP, &hTable_Jka8xjLg);
  numBytes += cVar_init_s(&cVar_IKyRlgPq, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_7q1kKr6R, 19.392f);
  numBytes += cDelay_init(this, &cDelay_CuVImasy, 0.0f);
  numBytes += cBinop_init(&cBinop_ds4AMR41, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_q8JY2Rz1, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_EfLroEe0, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ppfXEzes, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_bJvEkD2I, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dpgntKfU, 0.0f);
  numBytes += hTable_init(&hTable_2uj5YxwG, 256);
  numBytes += cTabhead_init(&cTabhead_uCbeNXpV, &hTable_2uj5YxwG);
  numBytes += cVar_init_s(&cVar_xebNQcRz, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_l6pT83yb, 16.364f);
  numBytes += cDelay_init(this, &cDelay_xLMIJi25, 0.0f);
  numBytes += cBinop_init(&cBinop_nsMlBsCw, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_hfK9JrFd, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_MMkQjOv3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_aldc6gic, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_MBuhRjlT, 0.0f);
  numBytes += cDelay_init(this, &cDelay_8uRy1253, 0.0f);
  numBytes += hTable_init(&hTable_8O0gCo8i, 256);
  numBytes += cTabhead_init(&cTabhead_BpL6lLZj, &hTable_8O0gCo8i);
  numBytes += cVar_init_s(&cVar_3haIMTYF, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_o8LizZKQ, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_OKzfgyze, 0.0f);
  numBytes += cBinop_init(&cBinop_DVe1y8ou, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_21OS53cJ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_OMm3Oizj, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_eKpnxgBT, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_qjB2tIsY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wkwwG3Yw, 0.0f);
  numBytes += hTable_init(&hTable_Bo97sIs9, 256);
  numBytes += cTabhead_init(&cTabhead_iFVFwI2t, &hTable_Bo97sIs9);
  numBytes += cVar_init_s(&cVar_doe4sVsl, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_dwiY10yd, 7.645f);
  numBytes += cDelay_init(this, &cDelay_2eo68Ccm, 0.0f);
  numBytes += cBinop_init(&cBinop_vODBxTv7, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_Ehmam7bQ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_WiyHzUq5, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Qlc8YkfZ, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_3NoCbM0d, 0.0f);
  numBytes += cVar_init_f(&cVar_9SSED0mx, 0.0f);
  numBytes += cPack_init(&cPack_PeYXmJAV, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_6miJPc0C, 22050.0f);
  numBytes += cBinop_init(&cBinop_OCGFor4F, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6Fj9NAGv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xUumtjRD, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_H0ojwI1s, 22050.0f);
  numBytes += cBinop_init(&cBinop_b050hDs4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_sbeYoikH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sXpfjFBI, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_trP9xK6e, 22050.0f);
  numBytes += cBinop_init(&cBinop_hoxAKGIM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fdNcFzVT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bsc9ibju, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_wx5GSikK, 0.0f);
  numBytes += cVar_init_f(&cVar_34YX189G, 1000.0f);
  numBytes += cBinop_init(&cBinop_JVeJZQlT, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FaxYgj3y, 0.0f);
  numBytes += cVar_init_f(&cVar_HUGKnVDt, 0.0f);
  numBytes += cIf_init(&cIf_RmCzKcYI, false);
  numBytes += cDelay_init(this, &cDelay_scskPBdE, 0.0f);
  numBytes += cDelay_init(this, &cDelay_pKYHl1t8, 0.0f);
  numBytes += hTable_init(&hTable_ljosD6FB, 256);
  numBytes += cTabhead_init(&cTabhead_DJP3AXP2, &hTable_ljosD6FB);
  numBytes += cVar_init_s(&cVar_AfJbEMbS, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_XwF5bRc6, 150.0f);
  numBytes += cDelay_init(this, &cDelay_ae3fnqgj, 0.0f);
  numBytes += cBinop_init(&cBinop_J1MBzJnj, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_PJRY7r4I, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_YmhJnugk, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_fiV7Iwl9, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_oXG49wk4, 0.0f);
  numBytes += cVar_init_f(&cVar_C7NnIuQo, 0.0f);
  numBytes += cVar_init_f(&cVar_5zuemPxv, 0.0f);
  numBytes += cVar_init_f(&cVar_lfFOoFIh, 0.0f);
  numBytes += cVar_init_f(&cVar_Sslsi5Tu, 0.0f);
  numBytes += cVar_init_f(&cVar_c2FbJuk3, 0.0f);
  numBytes += cIf_init(&cIf_mwXpkthl, false);
  numBytes += cVar_init_f(&cVar_mSnf3SOK, 0.0f);
  numBytes += cIf_init(&cIf_0Zs6UDVb, false);
  numBytes += cSlice_init(&cSlice_TYmG8ewk, 1, -1);
  numBytes += cSlice_init(&cSlice_5mBlFGdd, 1, -1);
  numBytes += cVar_init_f(&cVar_wZSctSIf, 0.0f);
  numBytes += cIf_init(&cIf_KoQlJeJT, false);
  numBytes += cBinop_init(&cBinop_9IhOUWqC, 0.0f); // __neq
  numBytes += cIf_init(&cIf_3aWzdW2n, false);
  numBytes += cIf_init(&cIf_VaxGdPrN, false);
  numBytes += cIf_init(&cIf_CK3P2WPm, false);
  numBytes += cIf_init(&cIf_ZWJvd87m, true);
  numBytes += cIf_init(&cIf_ivHT4PL9, false);
  numBytes += sVarf_init(&sVarf_5PLINncd, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Ld3g1cBl, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_8Dsa5Syk, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_An33hC8q, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_FqV0Fs6A, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_uwBRB05F, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kHclYqcP, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_YAiJShzO, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_oupes67s, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_UfrnvYF6, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_NRR9axaq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_BFMl6c94, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_yrLDjnzJ, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_JG44SkLD);
  cPack_free(&cPack_BGHGI0ri);
  hTable_free(&hTable_YF2nvvfg);
  hTable_free(&hTable_w9caY7Uc);
  hTable_free(&hTable_I5hYQdPe);
  hTable_free(&hTable_81RcK0Og);
  hTable_free(&hTable_lcWhYsi7);
  cPack_free(&cPack_Tl8xzhKK);
  cPack_free(&cPack_tZZFKcTY);
  hTable_free(&hTable_G7vqWhgt);
  hTable_free(&hTable_g2aqpmME);
  hTable_free(&hTable_Jka8xjLg);
  hTable_free(&hTable_2uj5YxwG);
  hTable_free(&hTable_8O0gCo8i);
  hTable_free(&hTable_Bo97sIs9);
  cPack_free(&cPack_PeYXmJAV);
  hTable_free(&hTable_ljosD6FB);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_YF2nvvfg; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_w9caY7Uc; // del-1052-del1
    case 0xA2AC524D: return &hTable_I5hYQdPe; // del-1052-del2
    case 0xE36A35B: return &hTable_81RcK0Og; // del-1052-del3
    case 0x48CE0509: return &hTable_lcWhYsi7; // del-1052-del4
    case 0xE34D6E72: return &hTable_G7vqWhgt; // del-1052-ref1
    case 0x6A1027AB: return &hTable_g2aqpmME; // del-1052-ref2
    case 0xA37C6D49: return &hTable_Jka8xjLg; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_2uj5YxwG; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_8O0gCo8i; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_Bo97sIs9; // del-1052-ref5
    case 0xED65564F: return &hTable_ljosD6FB; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f9z9NnHd_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D4jcvcbP_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WTfWgqdo_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9S59uWue_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TGy26br0_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8coIzRxw_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6uQ5M3xB_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p7PtGAqz_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5q6CEmUW_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X6ZWXOzq_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7BTqB12h_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nayBxOBD_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FoloaZKh_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TvyHAR7z_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZmHaNCKP_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fGU4aIrK_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ieSZwpIF_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gz5bbhvw_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bMTUVmQR_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z9WrAuVw_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w2KkKjDI_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qmnwyZGY_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O2nfv7Gp_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mvVn7Lhh_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_NuS9aiSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_b27Jjjf3_sendMessage);
}

void Heavy_ChaffVerb::cVar_nnuydczy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5aj8PCRK_sendMessage);
}

void Heavy_ChaffVerb::cPack_JG44SkLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_vtukoKc8, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_qhCqaZ4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jvzy0js6, 0, m, &cVar_Jvzy0js6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qM4xkZAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_qhCqaZ4C_sendMessage);
}

void Heavy_ChaffVerb::cVar_Jvzy0js6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bcIcz4r0_sendMessage);
}

void Heavy_ChaffVerb::cPack_BGHGI0ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_T0NVDXRV, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_cXvS9dvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_9TcKBRJ7_sendMessage);
}

void Heavy_ChaffVerb::cVar_FYzZBpBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_1IFokgMu, 0, m);
}

void Heavy_ChaffVerb::cMsg_cdCNZmIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5HJ1Fl30_sendMessage);
}

void Heavy_ChaffVerb::cSystem_5HJ1Fl30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wYEBlwEC_sendMessage);
}

void Heavy_ChaffVerb::cDelay_BVGdGKy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BVGdGKy7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_m4mJcxsw, 0, m, &cDelay_m4mJcxsw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BVGdGKy7, 0, m, &cDelay_BVGdGKy7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3c2aRRH4, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_m4mJcxsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m4mJcxsw, m);
  cMsg_2bBflMkS_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_712b6wVK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_RWZ2jF8K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_bUx0x41T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NxAqll4r_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_YF2nvvfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RGckDzLW_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BVGdGKy7, 2, m, &cDelay_BVGdGKy7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0hymeujt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NxAqll4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YF2nvvfg, 0, m, &hTable_YF2nvvfg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wYEBlwEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_bUx0x41T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2bBflMkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YF2nvvfg, 0, m, &hTable_YF2nvvfg_sendMessage);
}

void Heavy_ChaffVerb::cCast_0hymeujt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BVGdGKy7, 0, m, &cDelay_BVGdGKy7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RGckDzLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_m4mJcxsw, 2, m, &cDelay_m4mJcxsw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RWZ2jF8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3c2aRRH4, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_1syYnS4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3CGZeeBU_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3CGZeeBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dbcvlYrn_sendMessage);
}

void Heavy_ChaffVerb::cVar_FVAJYB1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yyUdPhld_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_1jKqZ4um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_B1nkTw1L_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rNUcEcpT, m);
}

void Heavy_ChaffVerb::cBinop_dbcvlYrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LMTUOOZI, m);
}

void Heavy_ChaffVerb::cMsg_yyUdPhld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1jKqZ4um_sendMessage);
}

void Heavy_ChaffVerb::cBinop_B1nkTw1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0WEZb33N, m);
}

void Heavy_ChaffVerb::cMsg_ThL3HUW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eHOlk2eJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_eHOlk2eJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2skpmcRc_sendMessage);
}

void Heavy_ChaffVerb::cVar_iQIfPoUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xRMajYOt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_WpjTT3DV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_DzyFjvyY_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0gnUWy3M, m);
}

void Heavy_ChaffVerb::cBinop_2skpmcRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_d9Ae8n2Q, m);
}

void Heavy_ChaffVerb::cMsg_xRMajYOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WpjTT3DV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DzyFjvyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZqEBJQ5U, m);
}

void Heavy_ChaffVerb::cBinop_AbAmyRn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FYzZBpBe, 0, m, &cVar_FYzZBpBe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cjL29gQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5k5ivsbk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7RW7fgjq_sendMessage);
}

void Heavy_ChaffVerb::cCast_7RW7fgjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AbAmyRn1, HV_BINOP_DIVIDE, 0, m, &cBinop_AbAmyRn1_sendMessage);
}

void Heavy_ChaffVerb::cCast_5k5ivsbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AbAmyRn1, HV_BINOP_DIVIDE, 1, m, &cBinop_AbAmyRn1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bcIcz4r0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hYmdxDjk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b27Jjjf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_qM4xkZAB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hYmdxDjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AbAmyRn1, HV_BINOP_DIVIDE, 0, m, &cBinop_AbAmyRn1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9TcKBRJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_BGHGI0ri, 0, m, &cPack_BGHGI0ri_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5aj8PCRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_cjL29gQn_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_JG44SkLD, 0, m, &cPack_JG44SkLD_sendMessage);
}

void Heavy_ChaffVerb::cUnop_1V6pojx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VaxGdPrN, 0, m, &cIf_VaxGdPrN_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_MZnhuNOT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p7ZHYLM9_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUV4tEZF_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AbfRe2yD_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_p7ZHYLM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_96kFO69x_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_eUV4tEZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gyqY7qxL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_AbfRe2yD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b3dMZOos_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_x2swAg3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_PD4bgTjT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PD4bgTjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zW95CANt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_itAKmlI6_sendMessage);
}

void Heavy_ChaffVerb::cVar_LiEsnmFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_z19phIxF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xMzpxgPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I1VCxvQ3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_I1VCxvQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_56Irp49J, HV_BINOP_DIVIDE, 1, m, &cBinop_56Irp49J_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zW95CANt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VPGptPUo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VPGptPUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5H2KqyCc, m);
}

void Heavy_ChaffVerb::cMsg_i18z6y1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YEBVbOsv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YEBVbOsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_x2swAg3g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_itAKmlI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_aX7BAuvn, m);
}

void Heavy_ChaffVerb::cBinop_z19phIxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_LAa0aHT8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LAa0aHT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_56Irp49J, HV_BINOP_DIVIDE, 0, m, &cBinop_56Irp49J_sendMessage);
}

void Heavy_ChaffVerb::cBinop_56Irp49J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i18z6y1A_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_uYZy1pt5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6nyrF5dG, 0, m, &cSlice_6nyrF5dG_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_h9chedN5, 0, m, &cRandom_h9chedN5_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Zi0WRh4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_KZxAxM25_sendMessage);
}

void Heavy_ChaffVerb::cUnop_KZxAxM25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_MuZZykkb_sendMessage);
}

void Heavy_ChaffVerb::cRandom_h9chedN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_Zi0WRh4X_sendMessage);
}

void Heavy_ChaffVerb::cSlice_6nyrF5dG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_h9chedN5, 1, m, &cRandom_h9chedN5_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_R3C7eyfp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_ijHSTRq4_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_ijHSTRq4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aEz83Sk8_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_CjoSJo51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CjoSJo51, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjoSJo51, 0, m, &cDelay_CjoSJo51_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FaxYgj3y, 0, m, &cVar_FaxYgj3y_sendMessage);
}

void Heavy_ChaffVerb::cCast_aEz83Sk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ijHSTRq4_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjoSJo51, 0, m, &cDelay_CjoSJo51_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FaxYgj3y, 0, m, &cVar_FaxYgj3y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_q4ThEumb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jq2WDxAG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_jq2WDxAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ylNRMRkj_sendMessage);
}

void Heavy_ChaffVerb::cVar_FDTa85X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_88gOCAA8, HV_BINOP_MULTIPLY, 0, m, &cBinop_88gOCAA8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ijHSTRq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjoSJo51, 0, m, &cDelay_CjoSJo51_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DsncaMqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CjoSJo51, 2, m, &cDelay_CjoSJo51_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ylNRMRkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_88gOCAA8, HV_BINOP_MULTIPLY, 1, m, &cBinop_88gOCAA8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_88gOCAA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_DsncaMqV_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_z9rWTOU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cela2owG, HV_BINOP_SUBTRACT, 0, m, &cBinop_cela2owG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I8efcATH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hVO5SgNa_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hVO5SgNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pxMubSSH_sendMessage);
}

void Heavy_ChaffVerb::cVar_FtrV1wt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fTY1UPRP_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_JtjxluUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JtjxluUu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F4tNP0A2, 0, m, &cDelay_F4tNP0A2_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_r6fM3TnS, 0, m, &sTabread_r6fM3TnS_sendMessage);
}

void Heavy_ChaffVerb::cDelay_F4tNP0A2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F4tNP0A2, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_r6fM3TnS, 0, m, &sTabread_r6fM3TnS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F4tNP0A2, 0, m, &cDelay_F4tNP0A2_sendMessage);
}

void Heavy_ChaffVerb::sTabread_r6fM3TnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5gkqoEyN, HV_BINOP_SUBTRACT, 0, m, &cBinop_5gkqoEyN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_UPDhVn2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cugzhyhf, HV_BINOP_MAX, 0, m, &cBinop_Cugzhyhf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pxMubSSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UPDhVn2I, HV_BINOP_MULTIPLY, 0, m, &cBinop_UPDhVn2I_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cela2owG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_soa3Cynn_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_r6fM3TnS, 0, m, &sTabread_r6fM3TnS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5FSZ0pnY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JtTisLhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5gkqoEyN, HV_BINOP_SUBTRACT, 1, m, &cBinop_5gkqoEyN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F4tNP0A2, 2, m, &cDelay_F4tNP0A2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fTY1UPRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JtTisLhh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_soa3Cynn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JtjxluUu, 0, m, &cDelay_JtjxluUu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F4tNP0A2, 0, m, &cDelay_F4tNP0A2_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SIJxxDYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cugzhyhf, HV_BINOP_MAX, 1, m, &cBinop_Cugzhyhf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Cugzhyhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cela2owG, HV_BINOP_SUBTRACT, 1, m, &cBinop_cela2owG_sendMessage);
}

void Heavy_ChaffVerb::cCast_5FSZ0pnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JtjxluUu, 0, m, &cDelay_JtjxluUu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_stp4wITM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JtjxluUu, 2, m, &cDelay_JtjxluUu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5gkqoEyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_stp4wITM_sendMessage);
}

void Heavy_ChaffVerb::cCast_eCIYmRRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FtrV1wt6, 0, m, &cVar_FtrV1wt6_sendMessage);
  cMsg_I8efcATH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_z9rWTOU3, 0, m, &cTabhead_z9rWTOU3_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_RCc3GUxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSrIhny1, HV_BINOP_SUBTRACT, 0, m, &cBinop_qSrIhny1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ve9M2ORk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qdUOVsuk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qdUOVsuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_etMRUYOj_sendMessage);
}

void Heavy_ChaffVerb::cVar_eCmeQJpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FQenoWlO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_MHWrjmiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MHWrjmiA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QFbSobRz, 0, m, &cDelay_QFbSobRz_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0m3qdFvi, 0, m, &sTabread_0m3qdFvi_sendMessage);
}

void Heavy_ChaffVerb::cDelay_QFbSobRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QFbSobRz, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0m3qdFvi, 0, m, &sTabread_0m3qdFvi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QFbSobRz, 0, m, &cDelay_QFbSobRz_sendMessage);
}

void Heavy_ChaffVerb::sTabread_0m3qdFvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_BGKLXkTf, HV_BINOP_SUBTRACT, 0, m, &cBinop_BGKLXkTf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_J8gO2cm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EoBpXZ9U, HV_BINOP_MAX, 0, m, &cBinop_EoBpXZ9U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_etMRUYOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J8gO2cm9, HV_BINOP_MULTIPLY, 0, m, &cBinop_J8gO2cm9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qSrIhny1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6W4i83xP_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_0m3qdFvi, 0, m, &sTabread_0m3qdFvi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UBRx8hv8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lToQiI2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BGKLXkTf, HV_BINOP_SUBTRACT, 1, m, &cBinop_BGKLXkTf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QFbSobRz, 2, m, &cDelay_QFbSobRz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FQenoWlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lToQiI2l_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6W4i83xP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHWrjmiA, 0, m, &cDelay_MHWrjmiA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QFbSobRz, 0, m, &cDelay_QFbSobRz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vkTirlbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_EoBpXZ9U, HV_BINOP_MAX, 1, m, &cBinop_EoBpXZ9U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EoBpXZ9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qSrIhny1, HV_BINOP_SUBTRACT, 1, m, &cBinop_qSrIhny1_sendMessage);
}

void Heavy_ChaffVerb::cCast_UBRx8hv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHWrjmiA, 0, m, &cDelay_MHWrjmiA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_A3SpHqo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MHWrjmiA, 2, m, &cDelay_MHWrjmiA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BGKLXkTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_A3SpHqo1_sendMessage);
}

void Heavy_ChaffVerb::cCast_Kqsbff09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eCmeQJpV, 0, m, &cVar_eCmeQJpV_sendMessage);
  cMsg_ve9M2ORk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RCc3GUxr, 0, m, &cTabhead_RCc3GUxr_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_wYjfkz5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s1IfCv4n, HV_BINOP_SUBTRACT, 0, m, &cBinop_s1IfCv4n_sendMessage);
}

void Heavy_ChaffVerb::cMsg_evTQPtiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E6r5Ru8S_sendMessage);
}

void Heavy_ChaffVerb::cSystem_E6r5Ru8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HXfQ72h8_sendMessage);
}

void Heavy_ChaffVerb::cVar_Y6WD4HFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fJmhV4t7_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_dHnxAkE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dHnxAkE1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkrqCeQn, 0, m, &cDelay_hkrqCeQn_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YsdnoXKM, 0, m, &sTabread_YsdnoXKM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_hkrqCeQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hkrqCeQn, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YsdnoXKM, 0, m, &sTabread_YsdnoXKM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkrqCeQn, 0, m, &cDelay_hkrqCeQn_sendMessage);
}

void Heavy_ChaffVerb::sTabread_YsdnoXKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_p6FI3dYr, HV_BINOP_SUBTRACT, 0, m, &cBinop_p6FI3dYr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_LZYSE4Vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hAKkx5fM, HV_BINOP_MAX, 0, m, &cBinop_hAKkx5fM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HXfQ72h8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LZYSE4Vz, HV_BINOP_MULTIPLY, 0, m, &cBinop_LZYSE4Vz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_s1IfCv4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vh5d1jN6_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YsdnoXKM, 0, m, &sTabread_YsdnoXKM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wWJSZVaj_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fM7RvmcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p6FI3dYr, HV_BINOP_SUBTRACT, 1, m, &cBinop_p6FI3dYr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkrqCeQn, 2, m, &cDelay_hkrqCeQn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fJmhV4t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fM7RvmcN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vh5d1jN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dHnxAkE1, 0, m, &cDelay_dHnxAkE1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkrqCeQn, 0, m, &cDelay_hkrqCeQn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZE0TpkEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_hAKkx5fM, HV_BINOP_MAX, 1, m, &cBinop_hAKkx5fM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hAKkx5fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s1IfCv4n, HV_BINOP_SUBTRACT, 1, m, &cBinop_s1IfCv4n_sendMessage);
}

void Heavy_ChaffVerb::cCast_wWJSZVaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dHnxAkE1, 0, m, &cDelay_dHnxAkE1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_t06zKqsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dHnxAkE1, 2, m, &cDelay_dHnxAkE1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_p6FI3dYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_t06zKqsy_sendMessage);
}

void Heavy_ChaffVerb::cCast_KxPCen7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y6WD4HFO, 0, m, &cVar_Y6WD4HFO_sendMessage);
  cMsg_evTQPtiO_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wYjfkz5x, 0, m, &cTabhead_wYjfkz5x_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_QuQM6A2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RtZOvZwh, HV_BINOP_SUBTRACT, 0, m, &cBinop_RtZOvZwh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sgipj7uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Mfz8HJO9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Mfz8HJO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_99dsvrey_sendMessage);
}

void Heavy_ChaffVerb::cVar_fczWhhYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lGddpkmz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_fusv8m8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fusv8m8e, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GwalW2Bg, 0, m, &cDelay_GwalW2Bg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5MF1l418, 0, m, &sTabread_5MF1l418_sendMessage);
}

void Heavy_ChaffVerb::cDelay_GwalW2Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GwalW2Bg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5MF1l418, 0, m, &sTabread_5MF1l418_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GwalW2Bg, 0, m, &cDelay_GwalW2Bg_sendMessage);
}

void Heavy_ChaffVerb::sTabread_5MF1l418_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_53mC33Uw, HV_BINOP_SUBTRACT, 0, m, &cBinop_53mC33Uw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rPb6Ee3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YgeVlmuD, HV_BINOP_MAX, 0, m, &cBinop_YgeVlmuD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_99dsvrey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rPb6Ee3E, HV_BINOP_MULTIPLY, 0, m, &cBinop_rPb6Ee3E_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RtZOvZwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ovC6Yr1F_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5MF1l418, 0, m, &sTabread_5MF1l418_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kZPi5rGt_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QtoUmndu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_53mC33Uw, HV_BINOP_SUBTRACT, 1, m, &cBinop_53mC33Uw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GwalW2Bg, 2, m, &cDelay_GwalW2Bg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lGddpkmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QtoUmndu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ovC6Yr1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fusv8m8e, 0, m, &cDelay_fusv8m8e_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GwalW2Bg, 0, m, &cDelay_GwalW2Bg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CpkmZiQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_YgeVlmuD, HV_BINOP_MAX, 1, m, &cBinop_YgeVlmuD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YgeVlmuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RtZOvZwh, HV_BINOP_SUBTRACT, 1, m, &cBinop_RtZOvZwh_sendMessage);
}

void Heavy_ChaffVerb::cCast_kZPi5rGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fusv8m8e, 0, m, &cDelay_fusv8m8e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_p6QoUMDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fusv8m8e, 2, m, &cDelay_fusv8m8e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_53mC33Uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_p6QoUMDc_sendMessage);
}

void Heavy_ChaffVerb::cCast_pTMDyAlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fczWhhYI, 0, m, &cVar_fczWhhYI_sendMessage);
  cMsg_sgipj7uo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_QuQM6A2k, 0, m, &cTabhead_QuQM6A2k_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IKtkOjbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r4ZNfR46_sendMessage);
}

void Heavy_ChaffVerb::cSystem_r4ZNfR46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_M7TlCpM6_sendMessage);
}

void Heavy_ChaffVerb::cDelay_TiIJFmDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TiIJFmDH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPPhSiK9, 0, m, &cDelay_PPPhSiK9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TiIJFmDH, 0, m, &cDelay_TiIJFmDH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rseLYbiB, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_PPPhSiK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PPPhSiK9, m);
  cMsg_HpdMdz6a_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Vs7Wjymr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_FblrJky0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_KZNstOC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wyv09UrR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_w9caY7Uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0EGbyPFU_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TiIJFmDH, 2, m, &cDelay_TiIJFmDH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nHALnscd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Wyv09UrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_w9caY7Uc, 0, m, &hTable_w9caY7Uc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M7TlCpM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_KZNstOC1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HpdMdz6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_w9caY7Uc, 0, m, &hTable_w9caY7Uc_sendMessage);
}

void Heavy_ChaffVerb::cCast_nHALnscd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TiIJFmDH, 0, m, &cDelay_TiIJFmDH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0EGbyPFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPPhSiK9, 2, m, &cDelay_PPPhSiK9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FblrJky0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rseLYbiB, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_Cimo71OP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DdQ67tJX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DdQ67tJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CKlqScuW_sendMessage);
}

void Heavy_ChaffVerb::cDelay_SwMRznUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SwMRznUO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M9tPPwPH, 0, m, &cDelay_M9tPPwPH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SwMRznUO, 0, m, &cDelay_SwMRznUO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3AKmkRUc, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_M9tPPwPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M9tPPwPH, m);
  cMsg_1Xpywmp2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_3PJe0y2t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_jKEKrUXp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_mVVXL3gL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VBMVaM1V_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_I5hYQdPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kz5MOPRR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SwMRznUO, 2, m, &cDelay_SwMRznUO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wPPVG0ZR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VBMVaM1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_I5hYQdPe, 0, m, &hTable_I5hYQdPe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CKlqScuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_mVVXL3gL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1Xpywmp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_I5hYQdPe, 0, m, &hTable_I5hYQdPe_sendMessage);
}

void Heavy_ChaffVerb::cCast_wPPVG0ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SwMRznUO, 0, m, &cDelay_SwMRznUO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kz5MOPRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_M9tPPwPH, 2, m, &cDelay_M9tPPwPH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jKEKrUXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_3AKmkRUc, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_ZfxfaPC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ua8Z5PQo_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ua8Z5PQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rqNIbWel_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rwYThOag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rwYThOag, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9DyEEwnT, 0, m, &cDelay_9DyEEwnT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rwYThOag, 0, m, &cDelay_rwYThOag_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_D7NUIqpq, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_9DyEEwnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9DyEEwnT, m);
  cMsg_W8UVSkxh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_wIKeDLmL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_x0WVpsp1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_dns5QhSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VkNu1To5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_81RcK0Og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_deJ5WOZg_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rwYThOag, 2, m, &cDelay_rwYThOag_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iKqoXk8s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VkNu1To5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_81RcK0Og, 0, m, &hTable_81RcK0Og_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rqNIbWel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_dns5QhSK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W8UVSkxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_81RcK0Og, 0, m, &hTable_81RcK0Og_sendMessage);
}

void Heavy_ChaffVerb::cCast_iKqoXk8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rwYThOag, 0, m, &cDelay_rwYThOag_sendMessage);
}

void Heavy_ChaffVerb::cMsg_deJ5WOZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9DyEEwnT, 2, m, &cDelay_9DyEEwnT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_x0WVpsp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_D7NUIqpq, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_m11cfVDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tSmn5Ern_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tSmn5Ern_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EyH5N1z4_sendMessage);
}

void Heavy_ChaffVerb::cDelay_XooNIOTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XooNIOTk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uqiIkWcI, 0, m, &cDelay_uqiIkWcI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XooNIOTk, 0, m, &cDelay_XooNIOTk_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Ye1OuG4u, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_uqiIkWcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uqiIkWcI, m);
  cMsg_UVGqZrnx_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_eM9r5cN4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0aY2ZtVW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_rX3INTci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b0xHivK3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_lcWhYsi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z6zZkpRv_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XooNIOTk, 2, m, &cDelay_XooNIOTk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2fj97NsC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_b0xHivK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_lcWhYsi7, 0, m, &hTable_lcWhYsi7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EyH5N1z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_rX3INTci_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UVGqZrnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_lcWhYsi7, 0, m, &hTable_lcWhYsi7_sendMessage);
}

void Heavy_ChaffVerb::cCast_2fj97NsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XooNIOTk, 0, m, &cDelay_XooNIOTk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_z6zZkpRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_uqiIkWcI, 2, m, &cDelay_uqiIkWcI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0aY2ZtVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Ye1OuG4u, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_Tl8xzhKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_cylkODwp, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_tZZFKcTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_cCK8SawI, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_DwID7hFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_oRgtbxkO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oRgtbxkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_zfBC8fCk_sendMessage);
}

void Heavy_ChaffVerb::cVar_kKuDxKFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F3vZFm9o, HV_BINOP_MULTIPLY, 0, m, &cBinop_F3vZFm9o_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nki7jl8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HoJO6Bh6_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HoJO6Bh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9GnrCLhl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_F3vZFm9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Jh7uqKkA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Suo4GIhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F3vZFm9o, HV_BINOP_MULTIPLY, 1, m, &cBinop_F3vZFm9o_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9GnrCLhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Suo4GIhA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Jh7uqKkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OPErtCGZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OPErtCGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zzwUbEsu_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Lk5DusoI, m);
}

void Heavy_ChaffVerb::cBinop_zzwUbEsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_y97o7vwD, m);
}

void Heavy_ChaffVerb::cVar_APZFXISU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_4GtU24kP_sendMessage);
}

void Heavy_ChaffVerb::cVar_VlOwzHEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DwID7hFx_sendMessage);
}

void Heavy_ChaffVerb::cVar_bonT6GsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_RZLwPua8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_NItNdQ8e, 0, m, &cIf_NItNdQ8e_sendMessage);
}

void Heavy_ChaffVerb::cVar_Z9wUw8rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_MeP1UPx6_sendMessage);
}

void Heavy_ChaffVerb::cIf_NItNdQ8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Iywf6hxl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_3NoCbM0d, 0, m, &cVar_3NoCbM0d_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_RZLwPua8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NItNdQ8e, 1, m, &cIf_NItNdQ8e_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MeP1UPx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9jhCOqBg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9jhCOqBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9SSED0mx, 0, m, &cVar_9SSED0mx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GcUTu1YY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dPvfMipW_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dPvfMipW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jcVzJfyi_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zDuUzF87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zDuUzF87, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkSMAwHX, 0, m, &cDelay_hkSMAwHX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zDuUzF87, 0, m, &cDelay_zDuUzF87_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0Pl3dNIQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_hkSMAwHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hkSMAwHX, m);
  cMsg_KBjAd6pb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_sQviBSo2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_1bsAVS3j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_XMPwBhL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fZ8tE2o9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_G7vqWhgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3i3K360P_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zDuUzF87, 2, m, &cDelay_zDuUzF87_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0hRyKnIC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fZ8tE2o9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_G7vqWhgt, 0, m, &hTable_G7vqWhgt_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jcVzJfyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_XMPwBhL6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_KBjAd6pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_G7vqWhgt, 0, m, &hTable_G7vqWhgt_sendMessage);
}

void Heavy_ChaffVerb::cCast_0hRyKnIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zDuUzF87, 0, m, &cDelay_zDuUzF87_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3i3K360P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hkSMAwHX, 2, m, &cDelay_hkSMAwHX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1bsAVS3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_0Pl3dNIQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_C8NNnfoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iFvl9fSK, HV_BINOP_SUBTRACT, 0, m, &cBinop_iFvl9fSK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lutDnQbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TycBXijX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_TycBXijX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IDvTA7YI_sendMessage);
}

void Heavy_ChaffVerb::cVar_Eds6lj3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vifmESdu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_VlmMxUat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VlmMxUat, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5AfNx0ai, 0, m, &cDelay_5AfNx0ai_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Y35u61Z4, 0, m, &sTabread_Y35u61Z4_sendMessage);
}

void Heavy_ChaffVerb::cDelay_5AfNx0ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5AfNx0ai, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Y35u61Z4, 0, m, &sTabread_Y35u61Z4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5AfNx0ai, 0, m, &cDelay_5AfNx0ai_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Y35u61Z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_bQUCk6AR, HV_BINOP_SUBTRACT, 0, m, &cBinop_bQUCk6AR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rG9vBysS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8SeafQfN, HV_BINOP_MAX, 0, m, &cBinop_8SeafQfN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IDvTA7YI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rG9vBysS, HV_BINOP_MULTIPLY, 0, m, &cBinop_rG9vBysS_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iFvl9fSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hlHtWUTE_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Y35u61Z4, 0, m, &sTabread_Y35u61Z4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_juzukQ9R_sendMessage);
}

void Heavy_ChaffVerb::cSystem_maWOmtHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bQUCk6AR, HV_BINOP_SUBTRACT, 1, m, &cBinop_bQUCk6AR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5AfNx0ai, 2, m, &cDelay_5AfNx0ai_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vifmESdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_maWOmtHC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hlHtWUTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VlmMxUat, 0, m, &cDelay_VlmMxUat_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5AfNx0ai, 0, m, &cDelay_5AfNx0ai_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FwFAg4Bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_8SeafQfN, HV_BINOP_MAX, 1, m, &cBinop_8SeafQfN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8SeafQfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iFvl9fSK, HV_BINOP_SUBTRACT, 1, m, &cBinop_iFvl9fSK_sendMessage);
}

void Heavy_ChaffVerb::cCast_juzukQ9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VlmMxUat, 0, m, &cDelay_VlmMxUat_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GLfzEljb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VlmMxUat, 2, m, &cDelay_VlmMxUat_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bQUCk6AR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GLfzEljb_sendMessage);
}

void Heavy_ChaffVerb::cCast_Td9JGdlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Eds6lj3R, 0, m, &cVar_Eds6lj3R_sendMessage);
  cMsg_lutDnQbB_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_C8NNnfoA, 0, m, &cTabhead_C8NNnfoA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m2OBY37s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_36n23msc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_36n23msc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jQOlPhc5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_mn9KkFVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mn9KkFVS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z6hygjnf, 0, m, &cDelay_z6hygjnf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mn9KkFVS, 0, m, &cDelay_mn9KkFVS_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UUqDgrLU, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_z6hygjnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z6hygjnf, m);
  cMsg_Nk59Ui4B_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_5kyCMF9y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_be2xjSFX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_F9EM2SD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ofAdCJd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_g2aqpmME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Po66TmK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mn9KkFVS, 2, m, &cDelay_mn9KkFVS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OI1FXXvD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2ofAdCJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_g2aqpmME, 0, m, &hTable_g2aqpmME_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jQOlPhc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_F9EM2SD6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Nk59Ui4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_g2aqpmME, 0, m, &hTable_g2aqpmME_sendMessage);
}

void Heavy_ChaffVerb::cCast_OI1FXXvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mn9KkFVS, 0, m, &cDelay_mn9KkFVS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4Po66TmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_z6hygjnf, 2, m, &cDelay_z6hygjnf_sendMessage);
}

void Heavy_ChaffVerb::cMsg_be2xjSFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UUqDgrLU, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_LoVnC1s1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qEniSJLA, HV_BINOP_SUBTRACT, 0, m, &cBinop_qEniSJLA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WmfzDFEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dFW60pTB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dFW60pTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rwCimj9M_sendMessage);
}

void Heavy_ChaffVerb::cVar_RTM4oqO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YHpM9b1S_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_I9CSEhE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I9CSEhE4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OAOy2YXY, 0, m, &cDelay_OAOy2YXY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mmMhnqzW, 0, m, &sTabread_mmMhnqzW_sendMessage);
}

void Heavy_ChaffVerb::cDelay_OAOy2YXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OAOy2YXY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mmMhnqzW, 0, m, &sTabread_mmMhnqzW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OAOy2YXY, 0, m, &cDelay_OAOy2YXY_sendMessage);
}

void Heavy_ChaffVerb::sTabread_mmMhnqzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_FZHvTbuo, HV_BINOP_SUBTRACT, 0, m, &cBinop_FZHvTbuo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Vjq48qQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zzz5I2dZ, HV_BINOP_MAX, 0, m, &cBinop_Zzz5I2dZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rwCimj9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vjq48qQ6, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vjq48qQ6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qEniSJLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XAJD0Fty_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_mmMhnqzW, 0, m, &sTabread_mmMhnqzW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IvEh91qy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_E0V93svm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZHvTbuo, HV_BINOP_SUBTRACT, 1, m, &cBinop_FZHvTbuo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OAOy2YXY, 2, m, &cDelay_OAOy2YXY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YHpM9b1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E0V93svm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XAJD0Fty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I9CSEhE4, 0, m, &cDelay_I9CSEhE4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OAOy2YXY, 0, m, &cDelay_OAOy2YXY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uX711ijy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zzz5I2dZ, HV_BINOP_MAX, 1, m, &cBinop_Zzz5I2dZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Zzz5I2dZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qEniSJLA, HV_BINOP_SUBTRACT, 1, m, &cBinop_qEniSJLA_sendMessage);
}

void Heavy_ChaffVerb::cCast_IvEh91qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I9CSEhE4, 0, m, &cDelay_I9CSEhE4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5n8AcWgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I9CSEhE4, 2, m, &cDelay_I9CSEhE4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FZHvTbuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5n8AcWgI_sendMessage);
}

void Heavy_ChaffVerb::cCast_XvjjT6UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RTM4oqO0, 0, m, &cVar_RTM4oqO0_sendMessage);
  cMsg_WmfzDFEe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_LoVnC1s1, 0, m, &cTabhead_LoVnC1s1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QuHieZvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CzLcLlwc_sendMessage);
}

void Heavy_ChaffVerb::cSystem_CzLcLlwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_T3twXdAR_sendMessage);
}

void Heavy_ChaffVerb::cDelay_4FGqJnY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4FGqJnY7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0umwDOyP, 0, m, &cDelay_0umwDOyP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4FGqJnY7, 0, m, &cDelay_4FGqJnY7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AwMN1Bx7, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_0umwDOyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0umwDOyP, m);
  cMsg_cKLAKYps_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_kfM1lUkO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wxHZr5px_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_9n4MnQKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XtdqAFHm_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Jka8xjLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fz9MYGuO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4FGqJnY7, 2, m, &cDelay_4FGqJnY7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QQRQ6JCQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XtdqAFHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Jka8xjLg, 0, m, &hTable_Jka8xjLg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T3twXdAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_9n4MnQKJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cKLAKYps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Jka8xjLg, 0, m, &hTable_Jka8xjLg_sendMessage);
}

void Heavy_ChaffVerb::cCast_QQRQ6JCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4FGqJnY7, 0, m, &cDelay_4FGqJnY7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Fz9MYGuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_0umwDOyP, 2, m, &cDelay_0umwDOyP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wxHZr5px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AwMN1Bx7, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_UdgDecLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q8JY2Rz1, HV_BINOP_SUBTRACT, 0, m, &cBinop_q8JY2Rz1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_54Ro4N8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3dBnk7SX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_3dBnk7SX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8rDU3c5R_sendMessage);
}

void Heavy_ChaffVerb::cVar_IKyRlgPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AYraqqYC_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_7q1kKr6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7q1kKr6R, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CuVImasy, 0, m, &cDelay_CuVImasy_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ufg6585U, 0, m, &sTabread_Ufg6585U_sendMessage);
}

void Heavy_ChaffVerb::cDelay_CuVImasy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CuVImasy, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ufg6585U, 0, m, &sTabread_Ufg6585U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CuVImasy, 0, m, &cDelay_CuVImasy_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Ufg6585U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ppfXEzes, HV_BINOP_SUBTRACT, 0, m, &cBinop_ppfXEzes_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_ds4AMR41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EfLroEe0, HV_BINOP_MAX, 0, m, &cBinop_EfLroEe0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8rDU3c5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ds4AMR41, HV_BINOP_MULTIPLY, 0, m, &cBinop_ds4AMR41_sendMessage);
}

void Heavy_ChaffVerb::cBinop_q8JY2Rz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_28uTJk9T_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ufg6585U, 0, m, &sTabread_Ufg6585U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WcmTiTRY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Qf5CHgrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ppfXEzes, HV_BINOP_SUBTRACT, 1, m, &cBinop_ppfXEzes_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CuVImasy, 2, m, &cDelay_CuVImasy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AYraqqYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Qf5CHgrL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_28uTJk9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7q1kKr6R, 0, m, &cDelay_7q1kKr6R_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CuVImasy, 0, m, &cDelay_CuVImasy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_l8rKl1d4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_EfLroEe0, HV_BINOP_MAX, 1, m, &cBinop_EfLroEe0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_EfLroEe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q8JY2Rz1, HV_BINOP_SUBTRACT, 1, m, &cBinop_q8JY2Rz1_sendMessage);
}

void Heavy_ChaffVerb::cCast_WcmTiTRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7q1kKr6R, 0, m, &cDelay_7q1kKr6R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_I1gjDr1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7q1kKr6R, 2, m, &cDelay_7q1kKr6R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ppfXEzes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_I1gjDr1r_sendMessage);
}

void Heavy_ChaffVerb::cCast_gMVhnaBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IKyRlgPq, 0, m, &cVar_IKyRlgPq_sendMessage);
  cMsg_54Ro4N8z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UdgDecLP, 0, m, &cTabhead_UdgDecLP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jN1Lu6Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_feRDCwca_sendMessage);
}

void Heavy_ChaffVerb::cSystem_feRDCwca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yAcwmfJF_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bJvEkD2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bJvEkD2I, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dpgntKfU, 0, m, &cDelay_dpgntKfU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bJvEkD2I, 0, m, &cDelay_bJvEkD2I_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_z0p9VhpL, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_dpgntKfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dpgntKfU, m);
  cMsg_9pZxBkwh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_SwvT9vFi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_W1GkZNFD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Y2X1i9jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uWXncdgo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_2uj5YxwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_25e0Bnmr_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bJvEkD2I, 2, m, &cDelay_bJvEkD2I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xrXLd6Xl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uWXncdgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2uj5YxwG, 0, m, &hTable_2uj5YxwG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yAcwmfJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_Y2X1i9jI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9pZxBkwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2uj5YxwG, 0, m, &hTable_2uj5YxwG_sendMessage);
}

void Heavy_ChaffVerb::cCast_xrXLd6Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bJvEkD2I, 0, m, &cDelay_bJvEkD2I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_25e0Bnmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dpgntKfU, 2, m, &cDelay_dpgntKfU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W1GkZNFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_z0p9VhpL, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_uCbeNXpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hfK9JrFd, HV_BINOP_SUBTRACT, 0, m, &cBinop_hfK9JrFd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Es2jrWxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8peuKYYQ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8peuKYYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WntdH5W0_sendMessage);
}

void Heavy_ChaffVerb::cVar_xebNQcRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lkLXarTL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_l6pT83yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l6pT83yb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xLMIJi25, 0, m, &cDelay_xLMIJi25_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_K0fbaYQX, 0, m, &sTabread_K0fbaYQX_sendMessage);
}

void Heavy_ChaffVerb::cDelay_xLMIJi25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xLMIJi25, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_K0fbaYQX, 0, m, &sTabread_K0fbaYQX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xLMIJi25, 0, m, &cDelay_xLMIJi25_sendMessage);
}

void Heavy_ChaffVerb::sTabread_K0fbaYQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_aldc6gic, HV_BINOP_SUBTRACT, 0, m, &cBinop_aldc6gic_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_nsMlBsCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MMkQjOv3, HV_BINOP_MAX, 0, m, &cBinop_MMkQjOv3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WntdH5W0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nsMlBsCw, HV_BINOP_MULTIPLY, 0, m, &cBinop_nsMlBsCw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hfK9JrFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wsxnBYjs_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_K0fbaYQX, 0, m, &sTabread_K0fbaYQX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mlFfTLtA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_rObJRMXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aldc6gic, HV_BINOP_SUBTRACT, 1, m, &cBinop_aldc6gic_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xLMIJi25, 2, m, &cDelay_xLMIJi25_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lkLXarTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rObJRMXp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wsxnBYjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_l6pT83yb, 0, m, &cDelay_l6pT83yb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xLMIJi25, 0, m, &cDelay_xLMIJi25_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4DjD3WNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_MMkQjOv3, HV_BINOP_MAX, 1, m, &cBinop_MMkQjOv3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MMkQjOv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hfK9JrFd, HV_BINOP_SUBTRACT, 1, m, &cBinop_hfK9JrFd_sendMessage);
}

void Heavy_ChaffVerb::cCast_mlFfTLtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_l6pT83yb, 0, m, &cDelay_l6pT83yb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TYZinHLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_l6pT83yb, 2, m, &cDelay_l6pT83yb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aldc6gic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TYZinHLx_sendMessage);
}

void Heavy_ChaffVerb::cCast_bXsprY2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xebNQcRz, 0, m, &cVar_xebNQcRz_sendMessage);
  cMsg_Es2jrWxi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_uCbeNXpV, 0, m, &cTabhead_uCbeNXpV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FlsH29Xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yynOTIl0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_yynOTIl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WG0j97f5_sendMessage);
}

void Heavy_ChaffVerb::cDelay_MBuhRjlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MBuhRjlT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8uRy1253, 0, m, &cDelay_8uRy1253_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MBuhRjlT, 0, m, &cDelay_MBuhRjlT_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8a7dg4qE, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_8uRy1253_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8uRy1253, m);
  cMsg_MxNbr9Cd_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_wvHSQDCP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_l0sdLYRb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_PQHu2P7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ogW4piFI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_8O0gCo8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HBjIkvf5_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_MBuhRjlT, 2, m, &cDelay_MBuhRjlT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_otPFPupy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ogW4piFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8O0gCo8i, 0, m, &hTable_8O0gCo8i_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WG0j97f5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_PQHu2P7N_sendMessage);
}

void Heavy_ChaffVerb::cMsg_MxNbr9Cd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8O0gCo8i, 0, m, &hTable_8O0gCo8i_sendMessage);
}

void Heavy_ChaffVerb::cCast_otPFPupy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MBuhRjlT, 0, m, &cDelay_MBuhRjlT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HBjIkvf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_8uRy1253, 2, m, &cDelay_8uRy1253_sendMessage);
}

void Heavy_ChaffVerb::cMsg_l0sdLYRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8a7dg4qE, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_BpL6lLZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_21OS53cJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_21OS53cJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oDjx0RhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FCM6uBSP_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FCM6uBSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UD7OtR63_sendMessage);
}

void Heavy_ChaffVerb::cVar_3haIMTYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CmW3W9dV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_o8LizZKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_o8LizZKQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OKzfgyze, 0, m, &cDelay_OKzfgyze_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RUAlilQT, 0, m, &sTabread_RUAlilQT_sendMessage);
}

void Heavy_ChaffVerb::cDelay_OKzfgyze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OKzfgyze, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RUAlilQT, 0, m, &sTabread_RUAlilQT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OKzfgyze, 0, m, &cDelay_OKzfgyze_sendMessage);
}

void Heavy_ChaffVerb::sTabread_RUAlilQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_eKpnxgBT, HV_BINOP_SUBTRACT, 0, m, &cBinop_eKpnxgBT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_DVe1y8ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OMm3Oizj, HV_BINOP_MAX, 0, m, &cBinop_OMm3Oizj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UD7OtR63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DVe1y8ou, HV_BINOP_MULTIPLY, 0, m, &cBinop_DVe1y8ou_sendMessage);
}

void Heavy_ChaffVerb::cBinop_21OS53cJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AweSXAHC_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_RUAlilQT, 0, m, &sTabread_RUAlilQT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hZU31R0J_sendMessage);
}

void Heavy_ChaffVerb::cSystem_V1gYJ3GZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eKpnxgBT, HV_BINOP_SUBTRACT, 1, m, &cBinop_eKpnxgBT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OKzfgyze, 2, m, &cDelay_OKzfgyze_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CmW3W9dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_V1gYJ3GZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AweSXAHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_o8LizZKQ, 0, m, &cDelay_o8LizZKQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_OKzfgyze, 0, m, &cDelay_OKzfgyze_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2jh7hJEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_OMm3Oizj, HV_BINOP_MAX, 1, m, &cBinop_OMm3Oizj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OMm3Oizj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_21OS53cJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_21OS53cJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_hZU31R0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_o8LizZKQ, 0, m, &cDelay_o8LizZKQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9MJJszdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_o8LizZKQ, 2, m, &cDelay_o8LizZKQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eKpnxgBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9MJJszdq_sendMessage);
}

void Heavy_ChaffVerb::cCast_yZnyRftw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3haIMTYF, 0, m, &cVar_3haIMTYF_sendMessage);
  cMsg_oDjx0RhM_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_BpL6lLZj, 0, m, &cTabhead_BpL6lLZj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sqsUvYHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w3cNNZoA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_w3cNNZoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_R0MIXtBY_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qjB2tIsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qjB2tIsY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wkwwG3Yw, 0, m, &cDelay_wkwwG3Yw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qjB2tIsY, 0, m, &cDelay_qjB2tIsY_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bqjiApZL, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_wkwwG3Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wkwwG3Yw, m);
  cMsg_k31rm0FO_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_YSDsYLRk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_XHad0s17_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_6OomW9lO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bmtt8a9O_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_Bo97sIs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uhPkDXz8_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qjB2tIsY, 2, m, &cDelay_qjB2tIsY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vb4OiDQX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Bmtt8a9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Bo97sIs9, 0, m, &hTable_Bo97sIs9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_R0MIXtBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_6OomW9lO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_k31rm0FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Bo97sIs9, 0, m, &hTable_Bo97sIs9_sendMessage);
}

void Heavy_ChaffVerb::cCast_vb4OiDQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qjB2tIsY, 0, m, &cDelay_qjB2tIsY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uhPkDXz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wkwwG3Yw, 2, m, &cDelay_wkwwG3Yw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XHad0s17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_bqjiApZL, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_iFVFwI2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ehmam7bQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_Ehmam7bQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZOg6Ut9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QFXUaWbf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QFXUaWbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LpPyYIQx_sendMessage);
}

void Heavy_ChaffVerb::cVar_doe4sVsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yeVCqb1R_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_dwiY10yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dwiY10yd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2eo68Ccm, 0, m, &cDelay_2eo68Ccm_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_crpjM7df, 0, m, &sTabread_crpjM7df_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2eo68Ccm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2eo68Ccm, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_crpjM7df, 0, m, &sTabread_crpjM7df_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2eo68Ccm, 0, m, &cDelay_2eo68Ccm_sendMessage);
}

void Heavy_ChaffVerb::sTabread_crpjM7df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Qlc8YkfZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_Qlc8YkfZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_vODBxTv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WiyHzUq5, HV_BINOP_MAX, 0, m, &cBinop_WiyHzUq5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LpPyYIQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vODBxTv7, HV_BINOP_MULTIPLY, 0, m, &cBinop_vODBxTv7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ehmam7bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Glx5csU2_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_crpjM7df, 0, m, &sTabread_crpjM7df_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5tOjUARf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_paz7oSFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qlc8YkfZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_Qlc8YkfZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2eo68Ccm, 2, m, &cDelay_2eo68Ccm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_yeVCqb1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_paz7oSFG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Glx5csU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dwiY10yd, 0, m, &cDelay_dwiY10yd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2eo68Ccm, 0, m, &cDelay_2eo68Ccm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0ey0shCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_WiyHzUq5, HV_BINOP_MAX, 1, m, &cBinop_WiyHzUq5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WiyHzUq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ehmam7bQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_Ehmam7bQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_5tOjUARf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dwiY10yd, 0, m, &cDelay_dwiY10yd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qLVNhUXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dwiY10yd, 2, m, &cDelay_dwiY10yd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Qlc8YkfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qLVNhUXF_sendMessage);
}

void Heavy_ChaffVerb::cCast_jAdqsPzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_doe4sVsl, 0, m, &cVar_doe4sVsl_sendMessage);
  cMsg_ZOg6Ut9a_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iFVFwI2t, 0, m, &cTabhead_iFVFwI2t_sendMessage);
}

void Heavy_ChaffVerb::cVar_3NoCbM0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kKuDxKFE, 0, m, &cVar_kKuDxKFE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6miJPc0C, 0, m, &cVar_6miJPc0C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H0ojwI1s, 0, m, &cVar_H0ojwI1s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_trP9xK6e, 0, m, &cVar_trP9xK6e_sendMessage);
}

void Heavy_ChaffVerb::cVar_9SSED0mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_G974W7RL_sendMessage);
}

void Heavy_ChaffVerb::cPack_PeYXmJAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_BtEoMJDi, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_6miJPc0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OCGFor4F, HV_BINOP_MULTIPLY, 0, m, &cBinop_OCGFor4F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3Z71twnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5LKMiKle_sendMessage);
}

void Heavy_ChaffVerb::cSystem_5LKMiKle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mPSkYeSw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_OCGFor4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UP91xxwb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GiHhOvtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OCGFor4F, HV_BINOP_MULTIPLY, 1, m, &cBinop_OCGFor4F_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mPSkYeSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GiHhOvtb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UP91xxwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VsCH8R8n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VsCH8R8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yAwYKXVc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xUumtjRD, m);
}

void Heavy_ChaffVerb::cBinop_yAwYKXVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6Fj9NAGv, m);
}

void Heavy_ChaffVerb::cVar_H0ojwI1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b050hDs4, HV_BINOP_MULTIPLY, 0, m, &cBinop_b050hDs4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gAsejT1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lGpxBhXZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lGpxBhXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nuJYuqLA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_b050hDs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_WKk7Znd6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NaaCepEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b050hDs4, HV_BINOP_MULTIPLY, 1, m, &cBinop_b050hDs4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nuJYuqLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NaaCepEn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WKk7Znd6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5zyBMGaU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5zyBMGaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_u0QX53CW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_sXpfjFBI, m);
}

void Heavy_ChaffVerb::cBinop_u0QX53CW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sbeYoikH, m);
}

void Heavy_ChaffVerb::cVar_trP9xK6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hoxAKGIM, HV_BINOP_MULTIPLY, 0, m, &cBinop_hoxAKGIM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jACILsia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EBdMiDpH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_EBdMiDpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ITPYMVAe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_hoxAKGIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zu2VHBbR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3CYg5Cfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hoxAKGIM, HV_BINOP_MULTIPLY, 1, m, &cBinop_hoxAKGIM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ITPYMVAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3CYg5Cfu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zu2VHBbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_iGQRex3u_sendMessage);
}

void Heavy_ChaffVerb::cBinop_iGQRex3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ixZfiBm3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bsc9ibju, m);
}

void Heavy_ChaffVerb::cBinop_ixZfiBm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fdNcFzVT, m);
}

void Heavy_ChaffVerb::cBinop_zfBC8fCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_tZZFKcTY, 0, m, &cPack_tZZFKcTY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Iywf6hxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_3NoCbM0d, 0, m, &cVar_3NoCbM0d_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G974W7RL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_PeYXmJAV, 0, m, &cPack_PeYXmJAV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4GtU24kP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Tl8xzhKK, 0, m, &cPack_Tl8xzhKK_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_DAZqdg2v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_2qWaiUVR_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_2qWaiUVR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LKhgicFD_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_wx5GSikK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wx5GSikK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wx5GSikK, 0, m, &cDelay_wx5GSikK_sendMessage);
  cSwitchcase_uYZy1pt5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_LKhgicFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qWaiUVR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wx5GSikK, 0, m, &cDelay_wx5GSikK_sendMessage);
  cSwitchcase_uYZy1pt5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_nBtlttKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4BGuzGzl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4BGuzGzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lPzN2hHG_sendMessage);
}

void Heavy_ChaffVerb::cVar_34YX189G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JVeJZQlT, HV_BINOP_MULTIPLY, 0, m, &cBinop_JVeJZQlT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2qWaiUVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wx5GSikK, 0, m, &cDelay_wx5GSikK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wJeFhPh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wx5GSikK, 2, m, &cDelay_wx5GSikK_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lPzN2hHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JVeJZQlT, HV_BINOP_MULTIPLY, 1, m, &cBinop_JVeJZQlT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JVeJZQlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_wJeFhPh8_sendMessage);
}

void Heavy_ChaffVerb::cVar_FaxYgj3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_lUyWBq5B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_37Cda7P8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gpHxvZpz_sendMessage);
}

void Heavy_ChaffVerb::cVar_HUGKnVDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NHkqsLcc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_RmCzKcYI, 0, m, &cIf_RmCzKcYI_sendMessage);
}

void Heavy_ChaffVerb::cUnop_1Mk1isRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ld3g1cBl, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_Ld3g1cBl_sendMessage);
}

void Heavy_ChaffVerb::cUnop_DlDhlj25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ld3g1cBl, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_Ld3g1cBl_sendMessage);
}

void Heavy_ChaffVerb::cIf_RmCzKcYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_DlDhlj25_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_1Mk1isRB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_NHkqsLcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RmCzKcYI, 1, m, &cIf_RmCzKcYI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wOnpFJRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XK0AeHII_sendMessage);
}

void Heavy_ChaffVerb::cSystem_XK0AeHII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5IP1D3s9_sendMessage);
}

void Heavy_ChaffVerb::cDelay_scskPBdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_scskPBdE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pKYHl1t8, 0, m, &cDelay_pKYHl1t8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_scskPBdE, 0, m, &cDelay_scskPBdE_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ONUMy9Wr, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_pKYHl1t8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pKYHl1t8, m);
  cMsg_FaKLf8BM_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Tg8mV1qy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_9GgRbmjE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ZNNyEAR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0ZIIKS4z_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ljosD6FB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ikx9TjWq_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_scskPBdE, 2, m, &cDelay_scskPBdE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UYR9wn1P_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0ZIIKS4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ljosD6FB, 0, m, &hTable_ljosD6FB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5IP1D3s9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_ZNNyEAR6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FaKLf8BM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ljosD6FB, 0, m, &hTable_ljosD6FB_sendMessage);
}

void Heavy_ChaffVerb::cCast_UYR9wn1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_scskPBdE, 0, m, &cDelay_scskPBdE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ikx9TjWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_pKYHl1t8, 2, m, &cDelay_pKYHl1t8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9GgRbmjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ONUMy9Wr, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_DJP3AXP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PJRY7r4I, HV_BINOP_SUBTRACT, 0, m, &cBinop_PJRY7r4I_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GR02AO0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Agty8oMZ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Agty8oMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_mNBTi29D_sendMessage);
}

void Heavy_ChaffVerb::cVar_AfJbEMbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LOI63B1t_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_XwF5bRc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XwF5bRc6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ae3fnqgj, 0, m, &cDelay_ae3fnqgj_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Jub5sovz, 0, m, &sTabread_Jub5sovz_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ae3fnqgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ae3fnqgj, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Jub5sovz, 0, m, &sTabread_Jub5sovz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ae3fnqgj, 0, m, &cDelay_ae3fnqgj_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Jub5sovz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fiV7Iwl9, HV_BINOP_SUBTRACT, 0, m, &cBinop_fiV7Iwl9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_J1MBzJnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmhJnugk, HV_BINOP_MAX, 0, m, &cBinop_YmhJnugk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mNBTi29D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J1MBzJnj, HV_BINOP_MULTIPLY, 0, m, &cBinop_J1MBzJnj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PJRY7r4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_at5plSj7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Jub5sovz, 0, m, &sTabread_Jub5sovz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6KbFr8cC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QK43ipO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fiV7Iwl9, HV_BINOP_SUBTRACT, 1, m, &cBinop_fiV7Iwl9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ae3fnqgj, 2, m, &cDelay_ae3fnqgj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LOI63B1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QK43ipO7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_at5plSj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwF5bRc6, 0, m, &cDelay_XwF5bRc6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ae3fnqgj, 0, m, &cDelay_ae3fnqgj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GrhkaWe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmhJnugk, HV_BINOP_MAX, 1, m, &cBinop_YmhJnugk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YmhJnugk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PJRY7r4I, HV_BINOP_SUBTRACT, 1, m, &cBinop_PJRY7r4I_sendMessage);
}

void Heavy_ChaffVerb::cCast_6KbFr8cC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwF5bRc6, 0, m, &cDelay_XwF5bRc6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lcPRsVDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XwF5bRc6, 2, m, &cDelay_XwF5bRc6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_fiV7Iwl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lcPRsVDe_sendMessage);
}

void Heavy_ChaffVerb::cCast_0pfPATDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AfJbEMbS, 0, m, &cVar_AfJbEMbS_sendMessage);
  cMsg_GR02AO0Q_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DJP3AXP2, 0, m, &cTabhead_DJP3AXP2_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_buk6j1Nq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3meWK5EZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_3meWK5EZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BtgVuyV4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_oXG49wk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oupes67s, HV_BINOP_ADD, 0, m, &cBinop_oupes67s_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_NFLK5iXm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1Yhi60He_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_1Yhi60He_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XqQX8EkN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_C7NnIuQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_91l5ghBb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WJkMyV6s_sendMessage);
}

void Heavy_ChaffVerb::cVar_5zuemPxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lfFOoFIh, 0, m, &cVar_lfFOoFIh_sendMessage);
}

void Heavy_ChaffVerb::cVar_lfFOoFIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrLDjnzJ, HV_BINOP_ADD, 0, m, &cBinop_yrLDjnzJ_sendMessage);
}

void Heavy_ChaffVerb::cVar_Sslsi5Tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_An33hC8q, HV_BINOP_ADD, 0, m, &cBinop_An33hC8q_sendMessage);
}

void Heavy_ChaffVerb::cVar_c2FbJuk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wsSj8phQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_mwXpkthl, 0, m, &cIf_mwXpkthl_sendMessage);
}

void Heavy_ChaffVerb::cUnop_pU8xgxx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_An33hC8q, HV_BINOP_ADD, 1, m, &cBinop_An33hC8q_sendMessage);
}

void Heavy_ChaffVerb::cUnop_iaaRNkVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_An33hC8q, HV_BINOP_ADD, 1, m, &cBinop_An33hC8q_sendMessage);
}

void Heavy_ChaffVerb::cIf_mwXpkthl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_iaaRNkVl_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_pU8xgxx2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_wsSj8phQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mwXpkthl, 1, m, &cIf_mwXpkthl_sendMessage);
}

void Heavy_ChaffVerb::cVar_mSnf3SOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W08rLIXe_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_0Zs6UDVb, 0, m, &cIf_0Zs6UDVb_sendMessage);
}

void Heavy_ChaffVerb::cUnop_pLtB8LiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RKWXo01B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_2xY2naIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RKWXo01B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_0Zs6UDVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_2xY2naIK_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_pLtB8LiF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_W08rLIXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Zs6UDVb, 1, m, &cIf_0Zs6UDVb_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_RKWXo01B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TYmG8ewk, 0, m, &cSlice_TYmG8ewk_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5mBlFGdd, 0, m, &cSlice_5mBlFGdd_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WKQ0n1dc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_98dYzQjV_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_TYmG8ewk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_wZSctSIf, 0, m, &cVar_wZSctSIf_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wZSctSIf, 0, m, &cVar_wZSctSIf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_5mBlFGdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_9IhOUWqC, HV_BINOP_NEQ, 1, m, &cBinop_9IhOUWqC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wZSctSIf, 1, m, &cVar_wZSctSIf_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_9IhOUWqC, HV_BINOP_NEQ, 1, m, &cBinop_9IhOUWqC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wZSctSIf, 1, m, &cVar_wZSctSIf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_wZSctSIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UMyuezEn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kcchCSrU_sendMessage);
}

void Heavy_ChaffVerb::cIf_KoQlJeJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SXyRTvON_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9yIzeT0I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_9yIzeT0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wZSctSIf, 0, m, &cVar_wZSctSIf_sendMessage);
}

void Heavy_ChaffVerb::cCast_SXyRTvON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9IhOUWqC, HV_BINOP_NEQ, 1, m, &cBinop_9IhOUWqC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9IhOUWqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KoQlJeJT, 1, m, &cIf_KoQlJeJT_sendMessage);
}

void Heavy_ChaffVerb::cCast_98dYzQjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KoQlJeJT, 0, m, &cIf_KoQlJeJT_sendMessage);
}

void Heavy_ChaffVerb::cCast_WKQ0n1dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9IhOUWqC, HV_BINOP_NEQ, 0, m, &cBinop_9IhOUWqC_sendMessage);
}

void Heavy_ChaffVerb::cIf_3aWzdW2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_5zuemPxv, 0, m, &cVar_5zuemPxv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_VaxGdPrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_3aWzdW2n, 0, m, &cIf_3aWzdW2n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_CK3P2WPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_3aWzdW2n, 0, m, &cIf_3aWzdW2n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_ZWJvd87m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_3aWzdW2n, 0, m, &cIf_3aWzdW2n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_ivHT4PL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_C7NnIuQo, 0, m, &cVar_C7NnIuQo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_EC2Ck2wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sslsi5Tu, 0, m, &cVar_Sslsi5Tu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gyqY7qxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VaxGdPrN, 1, m, &cIf_VaxGdPrN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_96kFO69x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ZWJvd87m, 1, m, &cIf_ZWJvd87m_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OVhNU3Fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VaxGdPrN, 1, m, &cIf_VaxGdPrN_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_CK3P2WPm, 1, m, &cIf_CK3P2WPm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ZWJvd87m, 1, m, &cIf_ZWJvd87m_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QdUeQ6HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oXG49wk4, 0, m, &cVar_oXG49wk4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MuZZykkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_QdUeQ6HJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XqQX8EkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_C7NnIuQo, 0, m, &cVar_C7NnIuQo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ld3g1cBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YAiJShzO, HV_BINOP_MULTIPLY, 0, m, &cBinop_YAiJShzO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gpHxvZpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ld3g1cBl, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_Ld3g1cBl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_b3dMZOos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CK3P2WPm, 1, m, &cIf_CK3P2WPm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_An33hC8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K9aO3TBP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GFmcRnPj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FqV0Fs6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NuS9aiSu, 0, m, &cVar_NuS9aiSu_sendMessage);
}

void Heavy_ChaffVerb::cCast_K9aO3TBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqV0Fs6A, HV_BINOP_ADD, 1, m, &cBinop_FqV0Fs6A_sendMessage);
}

void Heavy_ChaffVerb::cCast_GFmcRnPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5zuemPxv, 0, m, &cVar_5zuemPxv_sendMessage);
}

void Heavy_ChaffVerb::cCast_kcchCSrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MZnhuNOT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_UMyuezEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OVhNU3Fb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_DyHrX8GB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VlOwzHEz, 0, m, &cVar_VlOwzHEz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YAiJShzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CK3P2WPm, 0, m, &cIf_CK3P2WPm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_f86yKFAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZWJvd87m, 0, m, &cIf_ZWJvd87m_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lX1sQZlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_1V6pojx9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_f86yKFAT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lUyWBq5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_dCEsVfF5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dCEsVfF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_lX1sQZlX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_37Cda7P8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FaxYgj3y, 1, m, &cVar_FaxYgj3y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bItenKJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FDTa85X1, 0, m, &cVar_FDTa85X1_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Tj21tzHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_34YX189G, 0, m, &cVar_34YX189G_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BtgVuyV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_5zuemPxv, 0, m, &cVar_5zuemPxv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oupes67s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfrnvYF6, HV_BINOP_MULTIPLY, 0, m, &cBinop_UfrnvYF6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UfrnvYF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ivHT4PL9, 0, m, &cIf_ivHT4PL9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NRR9axaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FqV0Fs6A, HV_BINOP_ADD, 0, m, &cBinop_FqV0Fs6A_sendMessage);
}

void Heavy_ChaffVerb::cCast_WJkMyV6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5zuemPxv, 0, m, &cVar_5zuemPxv_sendMessage);
}

void Heavy_ChaffVerb::cCast_91l5ghBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NRR9axaq, HV_BINOP_ADD, 1, m, &cBinop_NRR9axaq_sendMessage);
}

void Heavy_ChaffVerb::cCast_c2BlAhDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3aWzdW2n, 1, m, &cIf_3aWzdW2n_sendMessage);
}

void Heavy_ChaffVerb::cCast_8PdhmFOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_buk6j1Nq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Q77bRDLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oXG49wk4, 0, m, &cVar_oXG49wk4_sendMessage);
}

void Heavy_ChaffVerb::cCast_sAxrlY2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfrnvYF6, HV_BINOP_MULTIPLY, 1, m, &cBinop_UfrnvYF6_sendMessage);
}

void Heavy_ChaffVerb::cCast_0Btk1pnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NFLK5iXm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_fqvthkgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ivHT4PL9, 1, m, &cIf_ivHT4PL9_sendMessage);
}

void Heavy_ChaffVerb::cCast_kGtSHAjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oXG49wk4, 0, m, &cVar_oXG49wk4_sendMessage);
}

void Heavy_ChaffVerb::cCast_GAcZNgIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oupes67s, HV_BINOP_ADD, 1, m, &cBinop_oupes67s_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BFMl6c94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NRR9axaq, HV_BINOP_ADD, 0, m, &cBinop_NRR9axaq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yrLDjnzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BFMl6c94, HV_BINOP_MULTIPLY, 0, m, &cBinop_BFMl6c94_sendMessage);
}

void Heavy_ChaffVerb::cCast_V11K51fZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5zuemPxv, 0, m, &cVar_5zuemPxv_sendMessage);
}

void Heavy_ChaffVerb::cCast_4vOLHPoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BFMl6c94, HV_BINOP_MULTIPLY, 1, m, &cBinop_BFMl6c94_sendMessage);
}

void Heavy_ChaffVerb::cCast_uD4qg8WM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5zuemPxv, 0, m, &cVar_5zuemPxv_sendMessage);
}

void Heavy_ChaffVerb::cCast_8qL8OkJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrLDjnzJ, HV_BINOP_ADD, 1, m, &cBinop_yrLDjnzJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zS7O8Mu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UMyuezEn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kcchCSrU_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mvVn7Lhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GcUTu1YY_sendMessage(_c, 0, m);
  cMsg_m2OBY37s_sendMessage(_c, 0, m);
  cMsg_QuHieZvH_sendMessage(_c, 0, m);
  cMsg_jN1Lu6Rx_sendMessage(_c, 0, m);
  cMsg_FlsH29Xi_sendMessage(_c, 0, m);
  cMsg_sqsUvYHS_sendMessage(_c, 0, m);
  cMsg_cdCNZmIv_sendMessage(_c, 0, m);
  cMsg_IKtkOjbK_sendMessage(_c, 0, m);
  cMsg_Cimo71OP_sendMessage(_c, 0, m);
  cMsg_ZfxfaPC7_sendMessage(_c, 0, m);
  cMsg_m11cfVDb_sendMessage(_c, 0, m);
  cMsg_nki7jl8m_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kKuDxKFE, 0, m, &cVar_kKuDxKFE_sendMessage);
  cMsg_3Z71twnK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6miJPc0C, 0, m, &cVar_6miJPc0C_sendMessage);
  cMsg_gAsejT1R_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_H0ojwI1s, 0, m, &cVar_H0ojwI1s_sendMessage);
  cMsg_jACILsia_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_trP9xK6e, 0, m, &cVar_trP9xK6e_sendMessage);
  cMsg_xMzpxgPE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LiEsnmFN, 0, m, &cVar_LiEsnmFN_sendMessage);
  cMsg_q4ThEumb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FDTa85X1, 0, m, &cVar_FDTa85X1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_APZFXISU, 0, m, &cVar_APZFXISU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VlOwzHEz, 0, m, &cVar_VlOwzHEz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bonT6GsE, 0, m, &cVar_bonT6GsE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z9wUw8rc, 0, m, &cVar_Z9wUw8rc_sendMessage);
  cMsg_nBtlttKo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_34YX189G, 0, m, &cVar_34YX189G_sendMessage);
  cMsg_wOnpFJRo_sendMessage(_c, 0, m);
  cSwitchcase_R3C7eyfp_onMessage(_c, NULL, 0, m, NULL);
  cMsg_BtgVuyV4_sendMessage(_c, 0, m);
  cMsg_zS7O8Mu3_sendMessage(_c, 0, m);
  cMsg_XqQX8EkN_sendMessage(_c, 0, m);
  cSwitchcase_DAZqdg2v_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_FVAJYB1A, 0, m, &cVar_FVAJYB1A_sendMessage);
  cMsg_1syYnS4d_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iQIfPoUW, 0, m, &cVar_iQIfPoUW_sendMessage);
  cMsg_ThL3HUW0_sendMessage(_c, 0, m);
  cMsg_SIJxxDYC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FtrV1wt6, 0, m, &cVar_FtrV1wt6_sendMessage);
  cMsg_I8efcATH_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_z9rWTOU3, 0, m, &cTabhead_z9rWTOU3_sendMessage);
  cMsg_vkTirlbj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eCmeQJpV, 0, m, &cVar_eCmeQJpV_sendMessage);
  cMsg_ve9M2ORk_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RCc3GUxr, 0, m, &cTabhead_RCc3GUxr_sendMessage);
  cMsg_ZE0TpkEg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Y6WD4HFO, 0, m, &cVar_Y6WD4HFO_sendMessage);
  cMsg_evTQPtiO_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wYjfkz5x, 0, m, &cTabhead_wYjfkz5x_sendMessage);
  cMsg_CpkmZiQS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fczWhhYI, 0, m, &cVar_fczWhhYI_sendMessage);
  cMsg_sgipj7uo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_QuQM6A2k, 0, m, &cTabhead_QuQM6A2k_sendMessage);
  cMsg_FwFAg4Bj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Eds6lj3R, 0, m, &cVar_Eds6lj3R_sendMessage);
  cMsg_lutDnQbB_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_C8NNnfoA, 0, m, &cTabhead_C8NNnfoA_sendMessage);
  cMsg_uX711ijy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RTM4oqO0, 0, m, &cVar_RTM4oqO0_sendMessage);
  cMsg_WmfzDFEe_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_LoVnC1s1, 0, m, &cTabhead_LoVnC1s1_sendMessage);
  cMsg_l8rKl1d4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IKyRlgPq, 0, m, &cVar_IKyRlgPq_sendMessage);
  cMsg_54Ro4N8z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_UdgDecLP, 0, m, &cTabhead_UdgDecLP_sendMessage);
  cMsg_4DjD3WNs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xebNQcRz, 0, m, &cVar_xebNQcRz_sendMessage);
  cMsg_Es2jrWxi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_uCbeNXpV, 0, m, &cTabhead_uCbeNXpV_sendMessage);
  cMsg_2jh7hJEc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3haIMTYF, 0, m, &cVar_3haIMTYF_sendMessage);
  cMsg_oDjx0RhM_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_BpL6lLZj, 0, m, &cTabhead_BpL6lLZj_sendMessage);
  cMsg_0ey0shCS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_doe4sVsl, 0, m, &cVar_doe4sVsl_sendMessage);
  cMsg_ZOg6Ut9a_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iFVFwI2t, 0, m, &cTabhead_iFVFwI2t_sendMessage);
  cMsg_GrhkaWe4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AfJbEMbS, 0, m, &cVar_AfJbEMbS_sendMessage);
  cMsg_GR02AO0Q_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DJP3AXP2, 0, m, &cTabhead_DJP3AXP2_sendMessage);
}

void Heavy_ChaffVerb::cReceive_f9z9NnHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_bItenKJT_sendMessage);
}

void Heavy_ChaffVerb::cReceive_TGy26br0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mSnf3SOK, 0, m, &cVar_mSnf3SOK_sendMessage);
}

void Heavy_ChaffVerb::cReceive_WTfWgqdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HUGKnVDt, 0, m, &cVar_HUGKnVDt_sendMessage);
}

void Heavy_ChaffVerb::cReceive_D4jcvcbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YAiJShzO, HV_BINOP_MULTIPLY, 1, m, &cBinop_YAiJShzO_sendMessage);
}

void Heavy_ChaffVerb::cReceive_8coIzRxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8qL8OkJC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uD4qg8WM_sendMessage);
}

void Heavy_ChaffVerb::cReceive_6uQ5M3xB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4vOLHPoo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V11K51fZ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_nayBxOBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sslsi5Tu, 0, m, &cVar_Sslsi5Tu_sendMessage);
}

void Heavy_ChaffVerb::cReceive_FoloaZKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EC2Ck2wz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c2FbJuk3, 0, m, &cVar_c2FbJuk3_sendMessage);
}

void Heavy_ChaffVerb::cReceive_5q6CEmUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_Tj21tzHo_sendMessage);
}

void Heavy_ChaffVerb::cReceive_p7PtGAqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GAcZNgIr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kGtSHAjW_sendMessage);
}

void Heavy_ChaffVerb::cReceive_X6ZWXOzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sAxrlY2M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q77bRDLw_sendMessage);
}

void Heavy_ChaffVerb::cReceive_7BTqB12h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fqvthkgM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Btk1pnI_sendMessage);
}

void Heavy_ChaffVerb::cReceive_w2KkKjDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8Dsa5Syk, m);
}

void Heavy_ChaffVerb::cReceive_Z9WrAuVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kHclYqcP, m);
}

void Heavy_ChaffVerb::cReceive_O2nfv7Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_APZFXISU, 0, m, &cVar_APZFXISU_sendMessage);
}

void Heavy_ChaffVerb::cReceive_qmnwyZGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_DyHrX8GB_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ieSZwpIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nnuydczy, 0, m, &cVar_nnuydczy_sendMessage);
}

void Heavy_ChaffVerb::cReceive_fGU4aIrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cXvS9dvW, 0, m, &cVar_cXvS9dvW_sendMessage);
}

void Heavy_ChaffVerb::cReceive_ZmHaNCKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LiEsnmFN, 0, m, &cVar_LiEsnmFN_sendMessage);
}

void Heavy_ChaffVerb::cReceive_TvyHAR7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5PLINncd, m);
}

void Heavy_ChaffVerb::cReceive_bMTUVmQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uwBRB05F, m);
}

void Heavy_ChaffVerb::cReceive_Gz5bbhvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J1MBzJnj, HV_BINOP_MULTIPLY, 1, m, &cBinop_J1MBzJnj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0pfPATDt_sendMessage);
}

void Heavy_ChaffVerb::cReceive_9S59uWue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c2BlAhDj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8PdhmFOB_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_1IFokgMu, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_vtukoKc8, VOf(Bf4));
    __hv_line_f(&sLine_T0NVDXRV, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_9zQgcjLm, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_LMTUOOZI, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_0WEZb33N, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_rNUcEcpT, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_eK64ZKON, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_0GBEWgNR, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_jY42P5J5, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_d9Ae8n2Q, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_ZqEBJQ5U, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_0gnUWy3M, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Ht7FHk2X, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_LCBNfAQX, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_3c2aRRH4, VIf(I0));
    __hv_varread_f(&sVarf_aX7BAuvn, VOf(Bf2));
    __hv_rpole_f(&sRPole_yjdV9Ifb, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_PwMzVesj, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5H2KqyCc, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_5PLINncd, VOf(Bf1));
    __hv_tabread_f(&sTabread_Jub5sovz, VOf(Bf5));
    __hv_varread_f(&sVarf_uwBRB05F, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_ONUMy9Wr, VIf(Bf9));
    __hv_varread_f(&sVarf_kHclYqcP, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_r6fM3TnS, VOf(Bf9));
    __hv_varread_f(&sVarf_Lk5DusoI, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_y97o7vwD, VOf(Bf2));
    __hv_rpole_f(&sRPole_jmSuMbpx, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_BtEoMJDi, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_cCK8SawI, VOf(Bf2));
    __hv_tabread_f(&sTabread_Y35u61Z4, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_mmMhnqzW, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_Ufg6585U, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_K0fbaYQX, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_crpjM7df, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_RUAlilQT, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_0Pl3dNIQ, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_UUqDgrLU, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_AwMN1Bx7, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_z0p9VhpL, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_8a7dg4qE, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_bqjiApZL, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_0m3qdFvi, VOf(Bf9));
    __hv_varread_f(&sVarf_xUumtjRD, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_6Fj9NAGv, VOf(Bf3));
    __hv_rpole_f(&sRPole_jctrbMkd, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_YsdnoXKM, VOf(Bf3));
    __hv_varread_f(&sVarf_sXpfjFBI, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_sbeYoikH, VOf(Bf12));
    __hv_rpole_f(&sRPole_usYgsXdz, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_5MF1l418, VOf(Bf12));
    __hv_varread_f(&sVarf_Bsc9ibju, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_fdNcFzVT, VOf(Bf11));
    __hv_rpole_f(&sRPole_GmkMZkVb, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_rseLYbiB, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_3AKmkRUc, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_D7NUIqpq, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_Ye1OuG4u, VIf(Bf11));
    __hv_line_f(&sLine_cylkODwp, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_8Dsa5Syk, VOf(Bf3));
    __hv_mul_f(VIf(I0), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf11), VIf(Bf3), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf13), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
